Class: Google::Cloud::Ces::V1::Agent::LlmAgent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent.rb

Overview

Default agent type. The agent uses instructions and callbacks specified in the agent to perform the task using a large language model.