Class: Google::Cloud::Ces::V1::AgentTransfer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/example.rb

Overview

Represents an event indicating the transfer of a conversation to a different agent.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String (readonly)

Returns Output only. Display name of the agent.

Returns:

  • (::String)

    Output only. Display name of the agent.



237
238
239
240
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 237

class AgentTransfer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_agent::String

Returns Required. The agent to which the conversation is being transferred. The agent will handle the conversation from this point forward. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.

Returns:

  • (::String)

    Required. The agent to which the conversation is being transferred. The agent will handle the conversation from this point forward. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}



237
238
239
240
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 237

class AgentTransfer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end