Class: Google::Cloud::Ces::V1::AmbientSoundConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.

Defined Under Namespace

Modules: PrebuiltAmbientNoise

Instance Attribute Summary collapse

Instance Attribute Details

#gcs_uri::String

Returns Optional. Ambient noise as a mono-channel, 16kHz WAV file stored in Cloud Storage.

Note: Please make sure the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com has storage.objects.get permission to the Cloud Storage object.

Note: The following fields are mutually exclusive: gcs_uri, prebuilt_ambient_noise, prebuilt_ambient_sound. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Ambient noise as a mono-channel, 16kHz WAV file stored in Cloud Storage.

    Note: Please make sure the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com has storage.objects.get permission to the Cloud Storage object.

    Note: The following fields are mutually exclusive: gcs_uri, prebuilt_ambient_noise, prebuilt_ambient_sound. If a field in that set is populated, all other fields in the set will automatically be cleared.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 300

class AmbientSoundConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Prebuilt ambient noise.
  module PrebuiltAmbientNoise
    # Not specified.
    PREBUILT_AMBIENT_NOISE_UNSPECIFIED = 0

    # Ambient noise of a retail store.
    RETAIL_STORE = 1

    # Ambient noise of a convention hall.
    CONVENTION_HALL = 2

    # Ambient noise of a street.
    OUTDOOR = 3
  end
end

#prebuilt_ambient_noise::Google::Cloud::Ces::V1::AmbientSoundConfig::PrebuiltAmbientNoise

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated: prebuilt_ambient_noise is deprecated in favor of prebuilt_ambient_sound.

Note: The following fields are mutually exclusive: prebuilt_ambient_noise, gcs_uri, prebuilt_ambient_sound. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::AmbientSoundConfig::PrebuiltAmbientNoise)

    Optional. Deprecated: prebuilt_ambient_noise is deprecated in favor of prebuilt_ambient_sound.

    Note: The following fields are mutually exclusive: prebuilt_ambient_noise, gcs_uri, prebuilt_ambient_sound. If a field in that set is populated, all other fields in the set will automatically be cleared.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 300

class AmbientSoundConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Prebuilt ambient noise.
  module PrebuiltAmbientNoise
    # Not specified.
    PREBUILT_AMBIENT_NOISE_UNSPECIFIED = 0

    # Ambient noise of a retail store.
    RETAIL_STORE = 1

    # Ambient noise of a convention hall.
    CONVENTION_HALL = 2

    # Ambient noise of a street.
    OUTDOOR = 3
  end
end

#prebuilt_ambient_sound::String

Returns Optional. Name of the prebuilt ambient sound. Valid values are:

  • "coffee_shop"
  • "keyboard"
  • "keypad"
  • "hum"
  • "office_1"
  • "office_2"
  • "office_3"
  • "room_1"
  • "room_2"
  • "room_3"
  • "room_4"
  • "room_5"
  • "air_conditioner"

Note: The following fields are mutually exclusive: prebuilt_ambient_sound, prebuilt_ambient_noise, gcs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Name of the prebuilt ambient sound. Valid values are:

    • "coffee_shop"
    • "keyboard"
    • "keypad"
    • "hum"
    • "office_1"
    • "office_2"
    • "office_3"
    • "room_1"
    • "room_2"
    • "room_3"
    • "room_4"
    • "room_5"
    • "air_conditioner"

    Note: The following fields are mutually exclusive: prebuilt_ambient_sound, prebuilt_ambient_noise, gcs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 300

class AmbientSoundConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Prebuilt ambient noise.
  module PrebuiltAmbientNoise
    # Not specified.
    PREBUILT_AMBIENT_NOISE_UNSPECIFIED = 0

    # Ambient noise of a retail store.
    RETAIL_STORE = 1

    # Ambient noise of a convention hall.
    CONVENTION_HALL = 2

    # Ambient noise of a street.
    OUTDOOR = 3
  end
end

#volume_gain_db::Float

Returns Optional. Volume gain (in dB) of the normal native volume supported by ambient noise, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB) will play at approximately half the amplitude of the normal native signal amplitude. A value of +6.0 (dB) will play at approximately twice the amplitude of the normal native signal amplitude. We strongly recommend not to exceed +10 (dB) as there's usually no effective increase in loudness for any value greater than that.

Returns:

  • (::Float)

    Optional. Volume gain (in dB) of the normal native volume supported by ambient noise, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB) will play at approximately half the amplitude of the normal native signal amplitude. A value of +6.0 (dB) will play at approximately twice the amplitude of the normal native signal amplitude. We strongly recommend not to exceed +10 (dB) as there's usually no effective increase in loudness for any value greater than that.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 300

class AmbientSoundConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Prebuilt ambient noise.
  module PrebuiltAmbientNoise
    # Not specified.
    PREBUILT_AMBIENT_NOISE_UNSPECIFIED = 0

    # Ambient noise of a retail store.
    RETAIL_STORE = 1

    # Ambient noise of a convention hall.
    CONVENTION_HALL = 2

    # Ambient noise of a street.
    OUTDOOR = 3
  end
end