Class: Google::Cloud::Ces::V1::ApiAuthentication

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/auth.rb

Overview

Authentication information required for API calls.

Instance Attribute Summary collapse

Instance Attribute Details

#api_key_config::Google::Cloud::Ces::V1::ApiKeyConfig

Returns Optional. Config for API key auth.

Note: The following fields are mutually exclusive: api_key_config, oauth_config, service_agent_id_token_auth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::ApiKeyConfig)

    Optional. Config for API key auth.

    Note: The following fields are mutually exclusive: api_key_config, oauth_config, service_agent_id_token_auth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 207

class ApiAuthentication
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#bearer_token_config::Google::Cloud::Ces::V1::BearerTokenConfig

Returns Optional. Config for bearer token auth.

Note: The following fields are mutually exclusive: bearer_token_config, api_key_config, oauth_config, service_agent_id_token_auth_config, service_account_auth_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::BearerTokenConfig)

    Optional. Config for bearer token auth.

    Note: The following fields are mutually exclusive: bearer_token_config, api_key_config, oauth_config, service_agent_id_token_auth_config, service_account_auth_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 207

class ApiAuthentication
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#oauth_config::Google::Cloud::Ces::V1::OAuthConfig

Returns Optional. Config for OAuth.

Note: The following fields are mutually exclusive: oauth_config, api_key_config, service_agent_id_token_auth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::OAuthConfig)

    Optional. Config for OAuth.

    Note: The following fields are mutually exclusive: oauth_config, api_key_config, service_agent_id_token_auth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 207

class ApiAuthentication
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_account_auth_config::Google::Cloud::Ces::V1::ServiceAccountAuthConfig

Returns Optional. Config for service account authentication.

Note: The following fields are mutually exclusive: service_account_auth_config, api_key_config, oauth_config, service_agent_id_token_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::ServiceAccountAuthConfig)

    Optional. Config for service account authentication.

    Note: The following fields are mutually exclusive: service_account_auth_config, api_key_config, oauth_config, service_agent_id_token_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 207

class ApiAuthentication
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_agent_id_token_auth_config::Google::Cloud::Ces::V1::ServiceAgentIdTokenAuthConfig

Returns Optional. Config for ID token auth generated from CES service agent.

Note: The following fields are mutually exclusive: service_agent_id_token_auth_config, api_key_config, oauth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::ServiceAgentIdTokenAuthConfig)

    Optional. Config for ID token auth generated from CES service agent.

    Note: The following fields are mutually exclusive: service_agent_id_token_auth_config, api_key_config, oauth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 207

class ApiAuthentication
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end