Class: Google::Cloud::Ces::V1::BargeInConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

Configuration for how the user barge-in activities should be handled.

Instance Attribute Summary collapse

Instance Attribute Details

#barge_in_awareness::Boolean

Returns Optional. If enabled, the agent will adapt its next response based on the assumption that the user hasn't heard the full preceding agent message. This should not be used in scenarios where agent responses are displayed visually.

Returns:

  • (::Boolean)

    Optional. If enabled, the agent will adapt its next response based on the assumption that the user hasn't heard the full preceding agent message. This should not be used in scenarios where agent responses are displayed visually.



336
337
338
339
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 336

class BargeInConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disable_barge_in::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Disables user barge-in while the agent is speaking. If true, user input during agent response playback will be ignored.

Deprecated: disable_barge_in is deprecated in favor of disable_barge_in_control in ChannelProfile.

Returns:

  • (::Boolean)

    Optional. Disables user barge-in while the agent is speaking. If true, user input during agent response playback will be ignored.

    Deprecated: disable_barge_in is deprecated in favor of disable_barge_in_control in ChannelProfile.



336
337
338
339
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 336

class BargeInConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end