Class: Google::Cloud::Ces::V1::BidiSessionClientMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/session_service.rb

Overview

The top-level message sent by the client for the SessionService.BidiRunSession method.

Instance Attribute Summary collapse

Instance Attribute Details

#config::Google::Cloud::Ces::V1::SessionConfig

Returns Optional. The initial config message for the session.

Note: The following fields are mutually exclusive: config, realtime_input. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::SessionConfig)

    Optional. The initial config message for the session.

    Note: The following fields are mutually exclusive: config, realtime_input. If a field in that set is populated, all other fields in the set will automatically be cleared.



408
409
410
411
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 408

class BidiSessionClientMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#realtime_input::Google::Cloud::Ces::V1::SessionInput

Returns Optional. Realtime input for the session.

Note: The following fields are mutually exclusive: realtime_input, config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::SessionInput)

    Optional. Realtime input for the session.

    Note: The following fields are mutually exclusive: realtime_input, config. If a field in that set is populated, all other fields in the set will automatically be cleared.



408
409
410
411
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 408

class BidiSessionClientMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end