Class: Google::Cloud::Ces::V1::Changelog

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/changelog.rb

Overview

Changelogs represent a change made to the app or to an resource within the app.

Instance Attribute Summary collapse

Instance Attribute Details

#action::String (readonly)

Returns Output only. The action that was performed on the resource.

Returns:

  • (::String)

    Output only. The action that was performed on the resource.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#author::String (readonly)

Returns Output only. Email address of the change author.

Returns:

  • (::String)

    Output only. Email address of the change author.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the change was made.

Returns:



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dependent_resources::Array<::Google::Protobuf::Struct> (readonly)

Returns Output only. The dependent resources that were changed.

Returns:



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String (readonly)

Returns Output only. Description of the change. which typically captures the changed fields in the resource.

Returns:

  • (::String)

    Output only. Description of the change. which typically captures the changed fields in the resource.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. Display name of the change. It typically should be the display name of the resource that was changed.

Returns:

  • (::String)

    Output only. Display name of the change. It typically should be the display name of the resource that was changed.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The unique identifier of the changelog. Format: projects/{project}/locations/{location}/apps/{app}/changelogs/{changelog}.

Returns:

  • (::String)

    Identifier. The unique identifier of the changelog. Format: projects/{project}/locations/{location}/apps/{app}/changelogs/{changelog}



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_resource::Google::Protobuf::Struct (readonly)

Returns Output only. The new resource after the change.

Returns:



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_resource::Google::Protobuf::Struct (readonly)

Returns Output only. The original resource before the change.

Returns:



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource::String (readonly)

Returns Output only. The resource that was changed.

Returns:

  • (::String)

    Output only. The resource that was changed.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_type::String (readonly)

Returns Output only. The type of the resource that was changed.

Returns:

  • (::String)

    Output only. The type of the resource that was changed.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sequence_number::Integer (readonly)

Returns Output only. The monotonically increasing sequence number of the changelog.

Returns:

  • (::Integer)

    Output only. The monotonically increasing sequence number of the changelog.



66
67
68
69
# File 'proto_docs/google/cloud/ces/v1/changelog.rb', line 66

class Changelog
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end