Class: Google::Cloud::Ces::V1::ChannelProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/common.rb

Overview

A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.

Defined Under Namespace

Modules: ChannelType Classes: PersonaProperty, WebWidgetConfig

Instance Attribute Summary collapse

Instance Attribute Details

#channel_type::Google::Cloud::Ces::V1::ChannelProfile::ChannelType

Returns Optional. The type of the channel profile.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end

#disable_barge_in_control::Boolean

Returns Optional. Whether to disable user barge-in control in the conversation.

  • true: User interruptions are disabled while the agent is speaking.
  • false: The agent retains automatic control over when the user can interrupt.

Returns:

  • (::Boolean)

    Optional. Whether to disable user barge-in control in the conversation.

    • true: User interruptions are disabled while the agent is speaking.
    • false: The agent retains automatic control over when the user can interrupt.


205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end

#disable_dtmf::Boolean

Returns Optional. Whether to disable DTMF (dual-tone multi-frequency).

Returns:

  • (::Boolean)

    Optional. Whether to disable DTMF (dual-tone multi-frequency).



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end

#noise_suppression_level::String

Returns Optional. The noise suppression level of the channel profile. Available values are "low", "moderate", "high", "very_high".

Returns:

  • (::String)

    Optional. The noise suppression level of the channel profile. Available values are "low", "moderate", "high", "very_high".



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end

#persona_property::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty

Returns Optional. The persona property of the channel profile.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end

#profile_id::String

Returns Optional. The unique identifier of the channel profile.

Returns:

  • (::String)

    Optional. The unique identifier of the channel profile.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end

#web_widget_config::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig

Returns Optional. The configuration for the web widget.

Returns:



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 205

class ChannelProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the persona property of a channel.
  # @!attribute [rw] persona
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::PersonaProperty::Persona]
  #     Optional. The persona of the channel.
  class PersonaProperty
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The persona of the channel.
    module Persona
      # UNKNOWN persona.
      UNKNOWN = 0

      # The agent keeps the responses concise and to the point
      CONCISE = 1

      # The agent provides additional context, explanations, and details
      CHATTY = 2
    end
  end

  # Message for configuration for the web widget.
  # @!attribute [rw] modality
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality]
  #     Optional. The modality of the web widget.
  # @!attribute [rw] theme
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme]
  #     Optional. The theme of the web widget.
  # @!attribute [rw] web_widget_title
  #   @return [::String]
  #     Optional. The title of the web widget.
  # @!attribute [rw] security_settings
  #   @return [::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings]
  #     Optional. The security settings of the web widget.
  class WebWidgetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Security settings for the web widget.
    # @!attribute [rw] enable_public_access
    #   @return [::Boolean]
    #     Optional. Indicates whether public access to the web widget is enabled.
    #     If `true`, the web widget will be publicly accessible.
    #     If `false`, the web widget must be integrated with your own
    #     authentication and authorization system to return valid credentials for
    #     accessing the CES agent.
    # @!attribute [rw] enable_origin_check
    #   @return [::Boolean]
    #     Optional. Indicates whether origin check for the web widget is enabled.
    #     If `true`, the web widget will check the origin of the website that
    #     loads the web widget and only allow it to be loaded in the same origin
    #     or any of the allowed origins.
    # @!attribute [rw] allowed_origins
    #   @return [::Array<::String>]
    #     Optional. The origins that are allowed to host the web widget. An
    #     origin is defined by RFC 6454. If empty, all origins are allowed. A
    #     maximum of 100 origins is allowed. Example: "https://example.com"
    # @!attribute [rw] enable_recaptcha
    #   @return [::Boolean]
    #     Optional. Indicates whether reCAPTCHA verification for the web widget
    #     is enabled.
    class SecuritySettings
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Modality of the web widget.
    module Modality
      # Unknown modality.
      MODALITY_UNSPECIFIED = 0

      # Widget supports both chat and voice input.
      CHAT_AND_VOICE = 1

      # Widget supports only voice input.
      VOICE_ONLY = 2

      # Widget supports only chat input.
      CHAT_ONLY = 3

      # Widget supports chat, voice, and video input.
      CHAT_VOICE_AND_VIDEO = 4
    end

    # Theme of the web widget.
    module Theme
      # Unknown theme.
      THEME_UNSPECIFIED = 0

      # Light theme.
      LIGHT = 1

      # Dark theme.
      DARK = 2
    end
  end

  # The type of the channel profile.
  module ChannelType
    # Unknown channel type.
    UNKNOWN = 0

    # Web UI channel.
    WEB_UI = 2

    # API channel.
    API = 3

    # Twilio channel.
    TWILIO = 4

    # Google Telephony Platform channel.
    GOOGLE_TELEPHONY_PLATFORM = 5

    # Contact Center as a Service (CCaaS) channel.
    CONTACT_CENTER_AS_A_SERVICE = 6

    # Five9 channel.
    FIVE9 = 7

    # Third party contact center integration channel.
    CONTACT_CENTER_INTEGRATION = 8
  end
end