Class: Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/common.rb

Overview

Message for configuration for the web widget.

Defined Under Namespace

Modules: Modality, Theme Classes: SecuritySettings

Instance Attribute Summary collapse

Instance Attribute Details

#modality::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Modality

Returns Optional. The modality of the web widget.

Returns:



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 243

class WebWidgetConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Security settings for the web widget.
  # @!attribute [rw] enable_public_access
  #   @return [::Boolean]
  #     Optional. Indicates whether public access to the web widget is enabled.
  #     If `true`, the web widget will be publicly accessible.
  #     If `false`, the web widget must be integrated with your own
  #     authentication and authorization system to return valid credentials for
  #     accessing the CES agent.
  # @!attribute [rw] enable_origin_check
  #   @return [::Boolean]
  #     Optional. Indicates whether origin check for the web widget is enabled.
  #     If `true`, the web widget will check the origin of the website that
  #     loads the web widget and only allow it to be loaded in the same origin
  #     or any of the allowed origins.
  # @!attribute [rw] allowed_origins
  #   @return [::Array<::String>]
  #     Optional. The origins that are allowed to host the web widget. An
  #     origin is defined by RFC 6454. If empty, all origins are allowed. A
  #     maximum of 100 origins is allowed. Example: "https://example.com"
  # @!attribute [rw] enable_recaptcha
  #   @return [::Boolean]
  #     Optional. Indicates whether reCAPTCHA verification for the web widget
  #     is enabled.
  class SecuritySettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Modality of the web widget.
  module Modality
    # Unknown modality.
    MODALITY_UNSPECIFIED = 0

    # Widget supports both chat and voice input.
    CHAT_AND_VOICE = 1

    # Widget supports only voice input.
    VOICE_ONLY = 2

    # Widget supports only chat input.
    CHAT_ONLY = 3

    # Widget supports chat, voice, and video input.
    CHAT_VOICE_AND_VIDEO = 4
  end

  # Theme of the web widget.
  module Theme
    # Unknown theme.
    THEME_UNSPECIFIED = 0

    # Light theme.
    LIGHT = 1

    # Dark theme.
    DARK = 2
  end
end

#security_settings::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::SecuritySettings

Returns Optional. The security settings of the web widget.

Returns:



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 243

class WebWidgetConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Security settings for the web widget.
  # @!attribute [rw] enable_public_access
  #   @return [::Boolean]
  #     Optional. Indicates whether public access to the web widget is enabled.
  #     If `true`, the web widget will be publicly accessible.
  #     If `false`, the web widget must be integrated with your own
  #     authentication and authorization system to return valid credentials for
  #     accessing the CES agent.
  # @!attribute [rw] enable_origin_check
  #   @return [::Boolean]
  #     Optional. Indicates whether origin check for the web widget is enabled.
  #     If `true`, the web widget will check the origin of the website that
  #     loads the web widget and only allow it to be loaded in the same origin
  #     or any of the allowed origins.
  # @!attribute [rw] allowed_origins
  #   @return [::Array<::String>]
  #     Optional. The origins that are allowed to host the web widget. An
  #     origin is defined by RFC 6454. If empty, all origins are allowed. A
  #     maximum of 100 origins is allowed. Example: "https://example.com"
  # @!attribute [rw] enable_recaptcha
  #   @return [::Boolean]
  #     Optional. Indicates whether reCAPTCHA verification for the web widget
  #     is enabled.
  class SecuritySettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Modality of the web widget.
  module Modality
    # Unknown modality.
    MODALITY_UNSPECIFIED = 0

    # Widget supports both chat and voice input.
    CHAT_AND_VOICE = 1

    # Widget supports only voice input.
    VOICE_ONLY = 2

    # Widget supports only chat input.
    CHAT_ONLY = 3

    # Widget supports chat, voice, and video input.
    CHAT_VOICE_AND_VIDEO = 4
  end

  # Theme of the web widget.
  module Theme
    # Unknown theme.
    THEME_UNSPECIFIED = 0

    # Light theme.
    LIGHT = 1

    # Dark theme.
    DARK = 2
  end
end

#theme::Google::Cloud::Ces::V1::ChannelProfile::WebWidgetConfig::Theme

Returns Optional. The theme of the web widget.

Returns:



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 243

class WebWidgetConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Security settings for the web widget.
  # @!attribute [rw] enable_public_access
  #   @return [::Boolean]
  #     Optional. Indicates whether public access to the web widget is enabled.
  #     If `true`, the web widget will be publicly accessible.
  #     If `false`, the web widget must be integrated with your own
  #     authentication and authorization system to return valid credentials for
  #     accessing the CES agent.
  # @!attribute [rw] enable_origin_check
  #   @return [::Boolean]
  #     Optional. Indicates whether origin check for the web widget is enabled.
  #     If `true`, the web widget will check the origin of the website that
  #     loads the web widget and only allow it to be loaded in the same origin
  #     or any of the allowed origins.
  # @!attribute [rw] allowed_origins
  #   @return [::Array<::String>]
  #     Optional. The origins that are allowed to host the web widget. An
  #     origin is defined by RFC 6454. If empty, all origins are allowed. A
  #     maximum of 100 origins is allowed. Example: "https://example.com"
  # @!attribute [rw] enable_recaptcha
  #   @return [::Boolean]
  #     Optional. Indicates whether reCAPTCHA verification for the web widget
  #     is enabled.
  class SecuritySettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Modality of the web widget.
  module Modality
    # Unknown modality.
    MODALITY_UNSPECIFIED = 0

    # Widget supports both chat and voice input.
    CHAT_AND_VOICE = 1

    # Widget supports only voice input.
    VOICE_ONLY = 2

    # Widget supports only chat input.
    CHAT_ONLY = 3

    # Widget supports chat, voice, and video input.
    CHAT_VOICE_AND_VIDEO = 4
  end

  # Theme of the web widget.
  module Theme
    # Unknown theme.
    THEME_UNSPECIFIED = 0

    # Light theme.
    LIGHT = 1

    # Dark theme.
    DARK = 2
  end
end

#web_widget_title::String

Returns Optional. The title of the web widget.

Returns:

  • (::String)

    Optional. The title of the web widget.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 243

class WebWidgetConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Security settings for the web widget.
  # @!attribute [rw] enable_public_access
  #   @return [::Boolean]
  #     Optional. Indicates whether public access to the web widget is enabled.
  #     If `true`, the web widget will be publicly accessible.
  #     If `false`, the web widget must be integrated with your own
  #     authentication and authorization system to return valid credentials for
  #     accessing the CES agent.
  # @!attribute [rw] enable_origin_check
  #   @return [::Boolean]
  #     Optional. Indicates whether origin check for the web widget is enabled.
  #     If `true`, the web widget will check the origin of the website that
  #     loads the web widget and only allow it to be loaded in the same origin
  #     or any of the allowed origins.
  # @!attribute [rw] allowed_origins
  #   @return [::Array<::String>]
  #     Optional. The origins that are allowed to host the web widget. An
  #     origin is defined by RFC 6454. If empty, all origins are allowed. A
  #     maximum of 100 origins is allowed. Example: "https://example.com"
  # @!attribute [rw] enable_recaptcha
  #   @return [::Boolean]
  #     Optional. Indicates whether reCAPTCHA verification for the web widget
  #     is enabled.
  class SecuritySettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Modality of the web widget.
  module Modality
    # Unknown modality.
    MODALITY_UNSPECIFIED = 0

    # Widget supports both chat and voice input.
    CHAT_AND_VOICE = 1

    # Widget supports only voice input.
    VOICE_ONLY = 2

    # Widget supports only chat input.
    CHAT_ONLY = 3

    # Widget supports chat, voice, and video input.
    CHAT_VOICE_AND_VIDEO = 4
  end

  # Theme of the web widget.
  module Theme
    # Unknown theme.
    THEME_UNSPECIFIED = 0

    # Light theme.
    LIGHT = 1

    # Dark theme.
    DARK = 2
  end
end