Class: Google::Cloud::Ces::V1::ClientFunction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/client_function.rb

Overview

Represents a client-side function that the agent can invoke. When the tool is chosen by the agent, control is handed off to the client. The client is responsible for executing the function and returning the result as a ToolResponse to continue the interaction with the agent.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. The function description.

Returns:

  • (::String)

    Optional. The function description.



41
42
43
44
# File 'proto_docs/google/cloud/ces/v1/client_function.rb', line 41

class ClientFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The function name.

Returns:

  • (::String)

    Required. The function name.



41
42
43
44
# File 'proto_docs/google/cloud/ces/v1/client_function.rb', line 41

class ClientFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parameters::Google::Cloud::Ces::V1::Schema

Returns Optional. The schema of the function parameters.

Returns:



41
42
43
44
# File 'proto_docs/google/cloud/ces/v1/client_function.rb', line 41

class ClientFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#response::Google::Cloud::Ces::V1::Schema

Returns Optional. The schema of the function response.

Returns:



41
42
43
44
# File 'proto_docs/google/cloud/ces/v1/client_function.rb', line 41

class ClientFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end