Class: Google::Cloud::Ces::V1::Conversation::Turn

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/conversation.rb

Overview

All information about a single turn in the conversation.

Instance Attribute Summary collapse

Instance Attribute Details

#messages::Array<::Google::Cloud::Ces::V1::Message>

Returns Optional. List of messages in the conversation turn, including user input, agent responses and intermediate events during the processing.

Returns:

  • (::Array<::Google::Cloud::Ces::V1::Message>)

    Optional. List of messages in the conversation turn, including user input, agent responses and intermediate events during the processing.



87
88
89
90
# File 'proto_docs/google/cloud/ces/v1/conversation.rb', line 87

class Turn
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#root_span::Google::Cloud::Ces::V1::Span

Returns Optional. The root span of the action processing.

Returns:



87
88
89
90
# File 'proto_docs/google/cloud/ces/v1/conversation.rb', line 87

class Turn
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end