Class: Google::Cloud::Ces::V1::CreateAgentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.CreateAgent.

Instance Attribute Summary collapse

Instance Attribute Details

#agent::Google::Cloud::Ces::V1::Agent

Returns Required. The agent to create.

Returns:



352
353
354
355
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 352

class CreateAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#agent_id::String

Returns Optional. The ID to use for the agent, which will become the final component of the agent's resource name. If not provided, a unique ID will be automatically assigned for the agent.

Returns:

  • (::String)

    Optional. The ID to use for the agent, which will become the final component of the agent's resource name. If not provided, a unique ID will be automatically assigned for the agent.



352
353
354
355
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 352

class CreateAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to create an agent in.

Returns:

  • (::String)

    Required. The resource name of the app to create an agent in.



352
353
354
355
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 352

class CreateAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end