Class: Google::Cloud::Ces::V1::CreateAppVersionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.CreateAppVersion

Instance Attribute Summary collapse

Instance Attribute Details

#app_version::Google::Cloud::Ces::V1::AppVersion

Returns Required. The app version to create.

Returns:



1157
1158
1159
1160
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1157

class CreateAppVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#app_version_id::String

Returns Optional. The ID to use for the app version, which will become the final component of the app version's resource name. If not provided, a unique ID will be automatically assigned for the app version.

Returns:

  • (::String)

    Optional. The ID to use for the app version, which will become the final component of the app version's resource name. If not provided, a unique ID will be automatically assigned for the app version.



1157
1158
1159
1160
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1157

class CreateAppVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to create an app version in.

Returns:

  • (::String)

    Required. The resource name of the app to create an app version in.



1157
1158
1159
1160
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1157

class CreateAppVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end