Class: Google::Cloud::Ces::V1::CreateExampleRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.CreateExample.

Instance Attribute Summary collapse

Instance Attribute Details

#example::Google::Cloud::Ces::V1::Example

Returns Required. The example to create.

Returns:



486
487
488
489
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 486

class CreateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#example_id::String

Returns Optional. The ID to use for the example, which will become the final component of the example's resource name. If not provided, a unique ID will be automatically assigned for the example.

Returns:

  • (::String)

    Optional. The ID to use for the example, which will become the final component of the example's resource name. If not provided, a unique ID will be automatically assigned for the example.



486
487
488
489
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 486

class CreateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to create an example in.

Returns:

  • (::String)

    Required. The resource name of the app to create an example in.



486
487
488
489
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 486

class CreateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end