Class: Google::Cloud::Ces::V1::CreateToolRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::CreateToolRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.CreateTool.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#tool ⇒ ::Google::Cloud::Ces::V1::Tool
Required.
-
#tool_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The resource name of the app to create a tool in.
589 590 591 592 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 589 class CreateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::Google::Cloud::Ces::V1::Tool
Returns Required. The tool to create.
589 590 591 592 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 589 class CreateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_id ⇒ ::String
Returns Optional. The ID to use for the tool, which will become the final component of the tool's resource name. If not provided, a unique ID will be automatically assigned for the tool.
589 590 591 592 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 589 class CreateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |