Class: Google::Cloud::Ces::V1::CreateToolsetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::CreateToolsetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.CreateToolset.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#toolset ⇒ ::Google::Cloud::Ces::V1::Toolset
Required.
-
#toolset_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The resource name of the app to create a toolset in.
1029 1030 1031 1032 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1029 class CreateToolsetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset ⇒ ::Google::Cloud::Ces::V1::Toolset
Returns Required. The toolset to create.
1029 1030 1031 1032 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1029 class CreateToolsetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_id ⇒ ::String
Returns Optional. The ID to use for the toolset, which will become the final component of the toolset's resource name. If not provided, a unique ID will be automatically assigned for the toolset.
1029 1030 1031 1032 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1029 class CreateToolsetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |