Class: Google::Cloud::Ces::V1::DataStore::ConnectorConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::DataStore::ConnectorConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/data_store.rb
Overview
The connector config for the data store connection.
Instance Attribute Summary collapse
-
#collection ⇒ ::String
Resource name of the collection the data store belongs to.
-
#collection_display_name ⇒ ::String
Display name of the collection the data store belongs to.
-
#data_source ⇒ ::String
The name of the data source.
Instance Attribute Details
#collection ⇒ ::String
Returns Resource name of the collection the data store belongs to.
62 63 64 65 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 62 class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#collection_display_name ⇒ ::String
Returns Display name of the collection the data store belongs to.
62 63 64 65 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 62 class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data_source ⇒ ::String
Returns The name of the data source.
Example: salesforce, jira, confluence, bigquery.
62 63 64 65 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 62 class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |