Class: Google::Cloud::Ces::V1::DataStoreSettings::Engine

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

An engine to which the data stores are connected. See Vertex AI Search: https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search-introduction.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#name::String (readonly)

Returns Output only. The resource name of the engine. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}.

Returns:

  • (::String)

    Output only. The resource name of the engine. Format: projects/{project}/locations/{location}/collections/{collection}/engines/{engine}



658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 658

class Engine
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the engine.
  # See the documentation available at
  # https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1/SolutionType
  # and
  # https://cloud.google.com/generative-ai-app-builder/docs/create-datastore-ingest.
  module Type
    # Unspecified engine type.
    TYPE_UNSPECIFIED = 0

    # The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores
    # added to the app will be added to this engine.
    ENGINE_TYPE_SEARCH = 1

    # Chat engine type.
    # The SOLUTION_TYPE_CHAT engine for the app. All connector data stores
    # added to the app will be added to this engine.
    ENGINE_TYPE_CHAT = 2
  end
end

#type::Google::Cloud::Ces::V1::DataStoreSettings::Engine::Type (readonly)

Returns Output only. The type of the engine.

Returns:



658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 658

class Engine
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the engine.
  # See the documentation available at
  # https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1/SolutionType
  # and
  # https://cloud.google.com/generative-ai-app-builder/docs/create-datastore-ingest.
  module Type
    # Unspecified engine type.
    TYPE_UNSPECIFIED = 0

    # The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores
    # added to the app will be added to this engine.
    ENGINE_TYPE_SEARCH = 1

    # Chat engine type.
    # The SOLUTION_TYPE_CHAT engine for the app. All connector data stores
    # added to the app will be added to this engine.
    ENGINE_TYPE_CHAT = 2
  end
end