Class: Google::Cloud::Ces::V1::DataStoreTool::EngineSource
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::DataStoreTool::EngineSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/data_store_tool.rb
Overview
Configuration for searching within an Engine, potentially targeting specific DataStores.
Instance Attribute Summary collapse
-
#data_store_sources ⇒ ::Array<::Google::Cloud::Ces::V1::DataStoreTool::DataStoreSource>
Optional.
-
#engine ⇒ ::String
Required.
-
#filter ⇒ ::String
Optional.
Instance Attribute Details
#data_store_sources ⇒ ::Array<::Google::Cloud::Ces::V1::DataStoreTool::DataStoreSource>
Returns Optional. Use to target specific DataStores within the Engine. If empty, the search applies to all DataStores associated with the Engine.
138 139 140 141 |
# File 'proto_docs/google/cloud/ces/v1/data_store_tool.rb', line 138 class EngineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#engine ⇒ ::String
Returns Required. Full resource name of the Engine.
Format:
projects/{project}/locations/{location}/collections/{collection}/engines/{engine}.
138 139 140 141 |
# File 'proto_docs/google/cloud/ces/v1/data_store_tool.rb', line 138 class EngineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Optional. A filter applied to the search across the Engine. Not relevant and not used if 'data_store_sources' is provided. See: https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata.
138 139 140 141 |
# File 'proto_docs/google/cloud/ces/v1/data_store_tool.rb', line 138 class EngineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |