Class: Google::Cloud::Ces::V1::DeleteConversationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::DeleteConversationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.DeleteConversation.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#source ⇒ ::Google::Cloud::Ces::V1::Conversation::Source
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The resource name of the conversation to delete.
707 708 709 710 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 707 class DeleteConversationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::Google::Cloud::Ces::V1::Conversation::Source
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Indicate the source of the conversation. If not set, Source.Live will be applied by default.
707 708 709 710 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 707 class DeleteConversationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |