Class: Google::Cloud::Ces::V1::DeleteToolRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.DeleteTool.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the tool. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the tool, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the tool. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the tool, deletion will be blocked and an ABORTED error will be returned.



628
629
630
631
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 628

class DeleteToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#force::Boolean

Returns Optional. Indicates whether to forcefully delete the tool, even if it is still referenced by agents/examples.

  • If force = false, the deletion will fail if any agents still reference the tool.
  • If force = true, all existing references from agents will be removed and the tool will be deleted.

Returns:

  • (::Boolean)

    Optional. Indicates whether to forcefully delete the tool, even if it is still referenced by agents/examples.

    • If force = false, the deletion will fail if any agents still reference the tool.
    • If force = true, all existing references from agents will be removed and the tool will be deleted.


628
629
630
631
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 628

class DeleteToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the tool to delete.

Returns:

  • (::String)

    Required. The resource name of the tool to delete.



628
629
630
631
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 628

class DeleteToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end