Class: Google::Cloud::Ces::V1::EndSession

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/session_service.rb

Overview

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation.

The agent will not process any further inputs after session is terminated and the client should half-close and disconnect after receiving all remaining responses from the agent.

Instance Attribute Summary collapse

Instance Attribute Details

#metadata::Google::Protobuf::Struct

Returns Optional. Provides additional information about the end session signal, such as the reason for ending the session.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. Provides additional information about the end session signal, such as the reason for ending the session.



360
361
362
363
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 360

class EndSession
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end