Class: Google::Cloud::Ces::V1::EndUserAuthConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/auth.rb

Overview

End-user authentication configuration used for Connection calls. The field values must be the names of context variables in the format $context.variables.<name_of_variable>.

Defined Under Namespace

Classes: Oauth2AuthCodeConfig, Oauth2JwtBearerConfig

Instance Attribute Summary collapse

Instance Attribute Details

#oauth2_auth_code_config::Google::Cloud::Ces::V1::EndUserAuthConfig::Oauth2AuthCodeConfig

Returns Oauth 2.0 Authorization Code authentication.

Note: The following fields are mutually exclusive: oauth2_auth_code_config, oauth2_jwt_bearer_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 148

class EndUserAuthConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Oauth 2.0 Authorization Code authentication configuration.
  # @!attribute [rw] oauth_token
  #   @return [::String]
  #     Required. Oauth token parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  class Oauth2AuthCodeConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # JWT Profile Oauth 2.0 Authorization Grant authentication configuration.
  # @!attribute [rw] issuer
  #   @return [::String]
  #     Required. Issuer parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  # @!attribute [rw] subject
  #   @return [::String]
  #     Required. Subject parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  # @!attribute [rw] client_key
  #   @return [::String]
  #     Required. Client parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  class Oauth2JwtBearerConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#oauth2_jwt_bearer_config::Google::Cloud::Ces::V1::EndUserAuthConfig::Oauth2JwtBearerConfig

Returns JWT Profile Oauth 2.0 Authorization Grant authentication.

Note: The following fields are mutually exclusive: oauth2_jwt_bearer_config, oauth2_auth_code_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::EndUserAuthConfig::Oauth2JwtBearerConfig)

    JWT Profile Oauth 2.0 Authorization Grant authentication.

    Note: The following fields are mutually exclusive: oauth2_jwt_bearer_config, oauth2_auth_code_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 148

class EndUserAuthConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Oauth 2.0 Authorization Code authentication configuration.
  # @!attribute [rw] oauth_token
  #   @return [::String]
  #     Required. Oauth token parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  class Oauth2AuthCodeConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # JWT Profile Oauth 2.0 Authorization Grant authentication configuration.
  # @!attribute [rw] issuer
  #   @return [::String]
  #     Required. Issuer parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  # @!attribute [rw] subject
  #   @return [::String]
  #     Required. Subject parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  # @!attribute [rw] client_key
  #   @return [::String]
  #     Required. Client parameter name to pass through.
  #     Must be in the format `$context.variables.<name_of_variable>`.
  class Oauth2JwtBearerConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end