Class: Google::Cloud::Ces::V1::ErrorHandlingSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

Settings to describe how errors should be handled in the app.

Defined Under Namespace

Modules: ErrorHandlingStrategy

Instance Attribute Summary collapse

Instance Attribute Details

#error_handling_strategy::Google::Cloud::Ces::V1::ErrorHandlingSettings::ErrorHandlingStrategy

Returns Optional. The strategy to use for error handling.

Returns:



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 409

class ErrorHandlingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the strategy for handling errors.
  module ErrorHandlingStrategy
    # Unspecified error handling strategy.
    ERROR_HANDLING_STRATEGY_UNSPECIFIED = 0

    # No specific handling is enabled.
    NONE = 1

    # A fallback message will be returned to the user in case of
    # system errors (e.g. LLM errors).
    FALLBACK_RESPONSE = 2

    # An {::Google::Cloud::Ces::V1::EndSession EndSession} signal will be emitted in
    # case of system errors (e.g. LLM errors).
    END_SESSION = 3
  end
end