Class: Google::Cloud::Ces::V1::ErrorHandlingSettings::FallbackResponseConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ErrorHandlingSettings::FallbackResponseConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/app.rb
Overview
Configuration for handling fallback responses.
Defined Under Namespace
Classes: CustomFallbackMessagesEntry
Instance Attribute Summary collapse
-
#custom_fallback_messages ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#max_fallback_attempts ⇒ ::Integer
Optional.
Instance Attribute Details
#custom_fallback_messages ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The fallback messages in case of system errors (e.g. LLM errors), mapped by supported language code.
468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 468 class FallbackResponseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomFallbackMessagesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#max_fallback_attempts ⇒ ::Integer
Returns Optional. The maximum number of fallback attempts to make before the agent emitting EndSession Signal.
468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 468 class FallbackResponseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomFallbackMessagesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |