Class: Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

Expectation level metrics thresholds.

Instance Attribute Summary collapse

Instance Attribute Details

#tool_invocation_parameter_correctness_threshold::Float

Returns Optional. The success threshold for individual tool invocation parameter correctness. Must be a float between 0 and 1. Default is 1.0.

Returns:

  • (::Float)

    Optional. The success threshold for individual tool invocation parameter correctness. Must be a float between 0 and 1. Default is 1.0.



500
501
502
503
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 500

class ExpectationLevelMetricsThresholds
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end