Module: Google::Cloud::Ces::V1::EvaluationMetricsThresholds::HallucinationMetricBehavior

Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

The hallucination metric behavior. Regardless of the behavior, the metric will always be calculated. The difference is that when disabled, the metric is not used to calculate the overall evaluation score.

Constant Summary collapse

HALLUCINATION_METRIC_BEHAVIOR_UNSPECIFIED =

Unspecified hallucination metric behavior.

0
DISABLED =

Disable hallucination metric.

1
ENABLED =

Enable hallucination metric.

2