Class: Google::Cloud::Ces::V1::EvaluationMetricsThresholds::ToolMatchingSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::EvaluationMetricsThresholds::ToolMatchingSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/app.rb
Overview
Settings for matching tool calls.
Defined Under Namespace
Modules: ExtraToolCallBehavior
Instance Attribute Summary collapse
Instance Attribute Details
#extra_tool_call_behavior ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior
Returns Optional. Behavior for extra tool calls. Defaults to FAIL.
511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 511 class ToolMatchingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the behavior when an extra tool call is encountered. An extra # tool call is a tool call that is present in the execution but does not # match any tool call in the golden expectation. module ExtraToolCallBehavior # Unspecified behavior. Defaults to FAIL. EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Fail the evaluation if an extra tool call is encountered. FAIL = 1 # Allow the extra tool call. ALLOW = 2 end end |