Class: Google::Cloud::Ces::V1::ExportAppRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ExportAppRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.ExportApp.
Defined Under Namespace
Modules: ExportFormat
Instance Attribute Summary collapse
-
#app_version ⇒ ::String
Optional.
-
#export_format ⇒ ::Google::Cloud::Ces::V1::ExportAppRequest::ExportFormat
Required.
-
#gcs_uri ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#app_version ⇒ ::String
Returns Optional. The resource name of the app version to export.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 148 class ExportAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Export format for the app. module ExportFormat # The export format is unspecified. EXPORT_FORMAT_UNSPECIFIED = 0 # The export format is JSON. JSON = 1 # The export format is YAML. YAML = 2 end end |
#export_format ⇒ ::Google::Cloud::Ces::V1::ExportAppRequest::ExportFormat
Returns Required. The format to export the app in.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 148 class ExportAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Export format for the app. module ExportFormat # The export format is unspecified. EXPORT_FORMAT_UNSPECIFIED = 0 # The export format is JSON. JSON = 1 # The export format is YAML. YAML = 2 end end |
#gcs_uri ⇒ ::String
Returns Optional. The Google Cloud
Storage URI to which to export the
app. The format of this URI must be gs://<bucket-name>/<object-name>. The
exported app archive will be written directly to the specified GCS object.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 148 class ExportAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Export format for the app. module ExportFormat # The export format is unspecified. EXPORT_FORMAT_UNSPECIFIED = 0 # The export format is JSON. JSON = 1 # The export format is YAML. YAML = 2 end end |
#name ⇒ ::String
Returns Required. The resource name of the app to export.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 148 class ExportAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Export format for the app. module ExportFormat # The export format is unspecified. EXPORT_FORMAT_UNSPECIFIED = 0 # The export format is JSON. JSON = 1 # The export format is YAML. YAML = 2 end end |