Class: Google::Cloud::Ces::V1::GenerateChatTokenRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::GenerateChatTokenRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/widget_service.rb
Overview
Request message for WidgetService.GenerateChatToken.
Instance Attribute Summary collapse
-
#deployment ⇒ ::String
Required.
-
#live_handoff_enabled ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
-
#recaptcha_token ⇒ ::String
Optional.
Instance Attribute Details
#deployment ⇒ ::String
Returns Required. The deployment of the app to use for the session. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}.
42 43 44 45 |
# File 'proto_docs/google/cloud/ces/v1/widget_service.rb', line 42 class GenerateChatTokenRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#live_handoff_enabled ⇒ ::Boolean
Returns Optional. Indicates if live handoff is enabled for the session.
42 43 44 45 |
# File 'proto_docs/google/cloud/ces/v1/widget_service.rb', line 42 class GenerateChatTokenRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The session name to generate the chat token for. Format: projects/{project}/locations/{location}/apps/{app}/sessions/{session}.
42 43 44 45 |
# File 'proto_docs/google/cloud/ces/v1/widget_service.rb', line 42 class GenerateChatTokenRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recaptcha_token ⇒ ::String
Returns Optional. The reCAPTCHA token generated by the client-side chat widget.
42 43 44 45 |
# File 'proto_docs/google/cloud/ces/v1/widget_service.rb', line 42 class GenerateChatTokenRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |