Class: Google::Cloud::Ces::V1::Guardrail::LlmPromptSecurity::DefaultSecuritySettings
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::Guardrail::LlmPromptSecurity::DefaultSecuritySettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/guardrail.rb
Overview
Configuration for default system security settings.
Instance Attribute Summary collapse
-
#default_prompt_template ⇒ ::String
readonly
Output only.
Instance Attribute Details
#default_prompt_template ⇒ ::String (readonly)
Returns Output only. The default prompt template used by the system. This field is for display purposes to show the user what prompt the system uses by default. It is OUTPUT_ONLY.
162 163 164 165 |
# File 'proto_docs/google/cloud/ces/v1/guardrail.rb', line 162 class DefaultSecuritySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |