Module: Google::Cloud::Ces::V1::ImportAppRequest::ImportOptions::ConflictResolutionStrategy
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Defines the strategy for handling conflicts when an app with the same ID already exists, or when imported resources (like Agents, Tools, etc.) have the same display names as existing resources within that app.
Constant Summary collapse
- CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED =
The conflict resolution strategy is unspecified.
0- REPLACE =
Replace existing data with imported data. If an app with the same
app_idalready exists, its content will be updated based on the imported app.- Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the imported app that have the same display name as existing resources will overwrite the existing ones.
- Imported resources with new display names will be created.
- Existing resources that do not have a matching display name in the imported app will remain untouched.
1- OVERWRITE =
Overwrite existing data with imported data. If an app with the same
app_idalready exists, its content will be overwritten with the imported app.- Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in the app will be deleted.
- Imported resources will be created as new resources.
2