Class: Google::Cloud::Ces::V1::InterruptionSignal
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::InterruptionSignal
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/session_service.rb
Overview
Indicates the agent's audio response has been interrupted. The client should immediately stop any current audio playback (e.g., due to user barge-in or a new agent response being generated).
Instance Attribute Summary collapse
-
#barge_in ⇒ ::Boolean
Whether the interruption is caused by a user barge-in event.
Instance Attribute Details
#barge_in ⇒ ::Boolean
Returns Whether the interruption is caused by a user barge-in event.
345 346 347 348 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 345 class InterruptionSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |