Class: Google::Cloud::Ces::V1::LanguageSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

Language settings of the app.

Instance Attribute Summary collapse

Instance Attribute Details

#default_language_code::String

Returns Optional. The default language code of the app.

Returns:

  • (::String)

    Optional. The default language code of the app.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 207

class LanguageSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_multilingual_support::Boolean

Returns Optional. Enables multilingual support. If true, agents in the app will use pre-built instructions to improve handling of multilingual input.

Returns:

  • (::Boolean)

    Optional. Enables multilingual support. If true, agents in the app will use pre-built instructions to improve handling of multilingual input.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 207

class LanguageSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fallback_action::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated: This feature is no longer supported. Use enable_multilingual_support instead to improve handling of multilingual input. The action to perform when an agent receives input in an unsupported language.

This can be a predefined action or a custom tool call. Valid values are:

  • A tool's full resource name, which triggers a specific tool execution.
  • A predefined system action, such as "escalate" or "exit", which triggers an EndSession signal with corresponding metadata to terminate the conversation.

Returns:

  • (::String)

    Optional. Deprecated: This feature is no longer supported. Use enable_multilingual_support instead to improve handling of multilingual input. The action to perform when an agent receives input in an unsupported language.

    This can be a predefined action or a custom tool call. Valid values are:

    • A tool's full resource name, which triggers a specific tool execution.
    • A predefined system action, such as "escalate" or "exit", which triggers an EndSession signal with corresponding metadata to terminate the conversation.


207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 207

class LanguageSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#supported_language_codes::Array<::String>

Returns Optional. List of languages codes supported by the app, in addition to the default_language_code.

Returns:

  • (::Array<::String>)

    Optional. List of languages codes supported by the app, in addition to the default_language_code.



207
208
209
210
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 207

class LanguageSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end