Class: Google::Cloud::Ces::V1::ListAppVersionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.ListAppVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter to be applied when listing the app versions. See https://google.aip.dev/160 for more details.

Returns:



1097
1098
1099
1100
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1097

class ListAppVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to sort by. Only "name" and "create_time" is supported. See https://google.aip.dev/132#ordering for more details.

Returns:



1097
1098
1099
1100
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1097

class ListAppVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



1097
1098
1099
1100
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1097

class ListAppVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous list AgentService.ListAppVersions call.

Returns:



1097
1098
1099
1100
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1097

class ListAppVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to list app versions from.

Returns:

  • (::String)

    Required. The resource name of the app to list app versions from.



1097
1098
1099
1100
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1097

class ListAppVersionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end