Class: Google::Cloud::Ces::V1::ListAppVersionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Response message for AgentService.ListAppVersions.

Instance Attribute Summary collapse

Instance Attribute Details

#app_versions::Array<::Google::Cloud::Ces::V1::AppVersion>

Returns The list of app versions.

Returns:



1113
1114
1115
1116
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1113

class ListAppVersionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as ListAppVersionsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as ListAppVersionsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.



1113
1114
1115
1116
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1113

class ListAppVersionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end