Class: Google::Cloud::Ces::V1::ListAppsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ListAppsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Response message for AgentService.ListApps.
Instance Attribute Summary collapse
-
#apps ⇒ ::Array<::Google::Cloud::Ces::V1::App>
The list of apps.
-
#next_page_token ⇒ ::String
A token that can be sent as ListAppsRequest.page_token to retrieve the next page.
-
#unreachable ⇒ ::Array<::String>
Unordered list.
Instance Attribute Details
#apps ⇒ ::Array<::Google::Cloud::Ces::V1::App>
Returns The list of apps.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 66 class ListAppsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as ListAppsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 66 class ListAppsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. Locations that could not be reached.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 66 class ListAppsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |