Class: Google::Cloud::Ces::V1::ListChangelogsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.ListChangelogs.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter to be applied when listing the changelogs. See https://google.aip.dev/160 for more details.

The filter string can be used to filter by action, resource_type, resource_name, author, and create_time. The : comparator can be used for case-insensitive partial matching on string fields, while = performs an exact case-sensitive match.

Examples:

  • action:update (case-insensitive partial match)
  • action="Create" (case-sensitive exact match)
  • resource_type:agent
  • resource_name:my-agent
  • author:me@example.com
  • create_time > "2025-01-01T00:00:00Z"
  • create_time <= "2025-01-01T00:00:00Z" AND resource_type:tool.

Returns:

  • (::String)

    Optional. Filter to be applied when listing the changelogs. See https://google.aip.dev/160 for more details.

    The filter string can be used to filter by action, resource_type, resource_name, author, and create_time. The : comparator can be used for case-insensitive partial matching on string fields, while = performs an exact case-sensitive match.

    Examples:

    • action:update (case-insensitive partial match)
    • action="Create" (case-sensitive exact match)
    • resource_type:agent
    • resource_name:my-agent
    • author:me@example.com
    • create_time > "2025-01-01T00:00:00Z"
    • create_time <= "2025-01-01T00:00:00Z" AND resource_type:tool


1217
1218
1219
1220
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1217

class ListChangelogsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to sort by. Only "name" and "create_time" is supported. See https://google.aip.dev/132#ordering for more details.

Returns:



1217
1218
1219
1220
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1217

class ListChangelogsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



1217
1218
1219
1220
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1217

class ListChangelogsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous list AgentService.ListChangelogs call.

Returns:



1217
1218
1219
1220
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1217

class ListChangelogsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to list changelogs from.

Returns:

  • (::String)

    Required. The resource name of the app to list changelogs from.



1217
1218
1219
1220
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1217

class ListChangelogsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end