Class: Google::Cloud::Ces::V1::ListChangelogsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Response message for AgentService.ListChangelogs.

Instance Attribute Summary collapse

Instance Attribute Details

#changelogs::Array<::Google::Cloud::Ces::V1::Changelog>

Returns The list of changelogs.

Returns:



1233
1234
1235
1236
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1233

class ListChangelogsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as ListChangelogsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as ListChangelogsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.



1233
1234
1235
1236
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1233

class ListChangelogsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end