Class: Google::Cloud::Ces::V1::ListDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ListDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Response message for AgentService.ListDeployments.
Instance Attribute Summary collapse
-
#deployments ⇒ ::Array<::Google::Cloud::Ces::V1::Deployment>
The list of deployments.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#deployments ⇒ ::Array<::Google::Cloud::Ces::V1::Deployment>
Returns The list of deployments.
894 895 896 897 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 894 class ListDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
894 895 896 897 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 894 class ListDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |