Class: Google::Cloud::Ces::V1::ListGuardrailsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Response message for AgentService.ListGuardrails.

Instance Attribute Summary collapse

Instance Attribute Details

#guardrails::Array<::Google::Cloud::Ces::V1::Guardrail>

Returns The list of guardrails.

Returns:



784
785
786
787
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 784

class ListGuardrailsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as ListGuardrailsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as ListGuardrailsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.



784
785
786
787
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 784

class ListGuardrailsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end