Class: Google::Cloud::Ces::V1::Message

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/example.rb

Overview

A message within a conversation.

Instance Attribute Summary collapse

Instance Attribute Details

#chunks::Array<::Google::Cloud::Ces::V1::Chunk>

Returns Optional. Content of the message as a series of chunks.

Returns:



77
78
79
80
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 77

class Message
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#event_time::Google::Protobuf::Timestamp

Returns Optional. Timestamp when the message was sent or received. Should not be used if the message is part of an example.

Returns:



77
78
79
80
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 77

class Message
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#role::String

Returns Optional. The role within the conversation, e.g., user, agent.

Returns:

  • (::String)

    Optional. The role within the conversation, e.g., user, agent.



77
78
79
80
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 77

class Message
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end