Class: Google::Cloud::Ces::V1::MetricAnalysisSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::MetricAnalysisSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/app.rb
Overview
Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline.
Instance Attribute Summary collapse
-
#llm_metrics_opted_out ⇒ ::Boolean
Optional.
Instance Attribute Details
#llm_metrics_opted_out ⇒ ::Boolean
Returns Optional. Whether to collect conversation data for llm analysis metrics. If true, conversation data will not be collected for llm analysis metrics; otherwise, conversation data will be collected.
368 369 370 371 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 368 class MetricAnalysisSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |