Class: Google::Cloud::Ces::V1::ModelSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/common.rb

Overview

Model settings contains various configurations for the LLM model.

Instance Attribute Summary collapse

Instance Attribute Details

#model::String

Returns Optional. The LLM model that the agent should use. If not set, the agent will inherit the model from its parent agent.

Returns:

  • (::String)

    Optional. The LLM model that the agent should use. If not set, the agent will inherit the model from its parent agent.



60
61
62
63
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 60

class ModelSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#temperature::Float

Returns Optional. If set, this temperature will be used for the LLM model. Temperature controls the randomness of the model's responses. Lower temperatures produce responses that are more predictable. Higher temperatures produce responses that are more creative.

Returns:

  • (::Float)

    Optional. If set, this temperature will be used for the LLM model. Temperature controls the randomness of the model's responses. Lower temperatures produce responses that are more predictable. Higher temperatures produce responses that are more creative.



60
61
62
63
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 60

class ModelSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end