Class: Google::Cloud::Ces::V1::OmnichannelIntegrationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/omnichannel.rb

Overview

OmnichannelIntegrationConfig contains all App integration configs.

Defined Under Namespace

Classes: CesAppConfig, ChannelConfig, ChannelConfigsEntry, RoutingConfig, RoutingConfigsEntry, SubscriberConfig, SubscriberConfigsEntry, WhatsappConfig

Instance Attribute Summary collapse

Instance Attribute Details

#channel_configs::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::ChannelConfig}

Returns Optional. Various of configuration for handling App events.

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 65

class OmnichannelIntegrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ChannelConfig contains config for various of app integration.
  # @!attribute [rw] whatsapp_config
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::WhatsappConfig]
  #     WhatsApp config.
  class ChannelConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # How Omnichannel should receive/reply events from WhatsApp.
  # @!attribute [rw] phone_number_id
  #   @return [::String]
  #     The Phone Number ID associated with the WhatsApp Business Account.
  # @!attribute [rw] phone_number
  #   @return [::String]
  #     The phone number used for sending/receiving messages.
  # @!attribute [rw] whatsapp_business_account_id
  #   @return [::String]
  #     The customer's WhatsApp Business Account (WABA) ID.
  # @!attribute [rw] webhook_verify_token
  #   @return [::String]
  #     The verify token configured in the Meta App Dashboard for webhook
  #     verification.
  # @!attribute [rw] whatsapp_business_token
  #   @return [::String]
  #     The access token for authenticating API calls to the WhatsApp Cloud API.
  #     https://developers.facebook.com/docs/whatsapp/business-management-api/get-started/#business-integration-system-user-access-tokens
  # @!attribute [rw] meta_business_portfolio_id
  #   @return [::String]
  #     The Meta Business Portfolio (MBP) ID.
  #     https://www.facebook.com/business/help/1710077379203657
  class WhatsappConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configs of subscribers.
  # @!attribute [rw] ces_app_config
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::CesAppConfig]
  #     Ces app config.
  class SubscriberConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configs for CES app.
  # @!attribute [rw] app
  #   @return [::String]
  #     The unique identifier of the CES app.
  #     Format: `projects/{project}/locations/{location}/apps/{app}`
  class CesAppConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing config specify how/who to route app events to a subscriber.
  # @!attribute [rw] subscriber_key
  #   @return [::String]
  #     The key of the subscriber.
  class RoutingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::ChannelConfig]
  class ChannelConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::SubscriberConfig]
  class SubscriberConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::RoutingConfig]
  class RoutingConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#routing_configs::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::RoutingConfig}

Returns Optional. The key of routing_configs is a key of app_configs, value is a RoutingConfig, which contains subscriber's key.

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 65

class OmnichannelIntegrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ChannelConfig contains config for various of app integration.
  # @!attribute [rw] whatsapp_config
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::WhatsappConfig]
  #     WhatsApp config.
  class ChannelConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # How Omnichannel should receive/reply events from WhatsApp.
  # @!attribute [rw] phone_number_id
  #   @return [::String]
  #     The Phone Number ID associated with the WhatsApp Business Account.
  # @!attribute [rw] phone_number
  #   @return [::String]
  #     The phone number used for sending/receiving messages.
  # @!attribute [rw] whatsapp_business_account_id
  #   @return [::String]
  #     The customer's WhatsApp Business Account (WABA) ID.
  # @!attribute [rw] webhook_verify_token
  #   @return [::String]
  #     The verify token configured in the Meta App Dashboard for webhook
  #     verification.
  # @!attribute [rw] whatsapp_business_token
  #   @return [::String]
  #     The access token for authenticating API calls to the WhatsApp Cloud API.
  #     https://developers.facebook.com/docs/whatsapp/business-management-api/get-started/#business-integration-system-user-access-tokens
  # @!attribute [rw] meta_business_portfolio_id
  #   @return [::String]
  #     The Meta Business Portfolio (MBP) ID.
  #     https://www.facebook.com/business/help/1710077379203657
  class WhatsappConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configs of subscribers.
  # @!attribute [rw] ces_app_config
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::CesAppConfig]
  #     Ces app config.
  class SubscriberConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configs for CES app.
  # @!attribute [rw] app
  #   @return [::String]
  #     The unique identifier of the CES app.
  #     Format: `projects/{project}/locations/{location}/apps/{app}`
  class CesAppConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing config specify how/who to route app events to a subscriber.
  # @!attribute [rw] subscriber_key
  #   @return [::String]
  #     The key of the subscriber.
  class RoutingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::ChannelConfig]
  class ChannelConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::SubscriberConfig]
  class SubscriberConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::RoutingConfig]
  class RoutingConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#subscriber_configs::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::SubscriberConfig}

Returns Optional. Various of subscribers configs.

Returns:



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 65

class OmnichannelIntegrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # ChannelConfig contains config for various of app integration.
  # @!attribute [rw] whatsapp_config
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::WhatsappConfig]
  #     WhatsApp config.
  class ChannelConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # How Omnichannel should receive/reply events from WhatsApp.
  # @!attribute [rw] phone_number_id
  #   @return [::String]
  #     The Phone Number ID associated with the WhatsApp Business Account.
  # @!attribute [rw] phone_number
  #   @return [::String]
  #     The phone number used for sending/receiving messages.
  # @!attribute [rw] whatsapp_business_account_id
  #   @return [::String]
  #     The customer's WhatsApp Business Account (WABA) ID.
  # @!attribute [rw] webhook_verify_token
  #   @return [::String]
  #     The verify token configured in the Meta App Dashboard for webhook
  #     verification.
  # @!attribute [rw] whatsapp_business_token
  #   @return [::String]
  #     The access token for authenticating API calls to the WhatsApp Cloud API.
  #     https://developers.facebook.com/docs/whatsapp/business-management-api/get-started/#business-integration-system-user-access-tokens
  # @!attribute [rw] meta_business_portfolio_id
  #   @return [::String]
  #     The Meta Business Portfolio (MBP) ID.
  #     https://www.facebook.com/business/help/1710077379203657
  class WhatsappConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configs of subscribers.
  # @!attribute [rw] ces_app_config
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::CesAppConfig]
  #     Ces app config.
  class SubscriberConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configs for CES app.
  # @!attribute [rw] app
  #   @return [::String]
  #     The unique identifier of the CES app.
  #     Format: `projects/{project}/locations/{location}/apps/{app}`
  class CesAppConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Routing config specify how/who to route app events to a subscriber.
  # @!attribute [rw] subscriber_key
  #   @return [::String]
  #     The key of the subscriber.
  class RoutingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::ChannelConfig]
  class ChannelConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::SubscriberConfig]
  class SubscriberConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::RoutingConfig]
  class RoutingConfigsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end