Class: Google::Cloud::Ces::V1::OmnichannelIntegrationConfig::WhatsappConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/omnichannel.rb

Overview

How Omnichannel should receive/reply events from WhatsApp.

Instance Attribute Summary collapse

Instance Attribute Details

#meta_business_portfolio_id::String

Returns The Meta Business Portfolio (MBP) ID. https://www.facebook.com/business/help/1710077379203657.

Returns:



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 100

class WhatsappConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phone_number::String

Returns The phone number used for sending/receiving messages.

Returns:

  • (::String)

    The phone number used for sending/receiving messages.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 100

class WhatsappConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phone_number_id::String

Returns The Phone Number ID associated with the WhatsApp Business Account.

Returns:

  • (::String)

    The Phone Number ID associated with the WhatsApp Business Account.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 100

class WhatsappConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#webhook_verify_token::String

Returns The verify token configured in the Meta App Dashboard for webhook verification.

Returns:

  • (::String)

    The verify token configured in the Meta App Dashboard for webhook verification.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 100

class WhatsappConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#whatsapp_business_account_id::String

Returns The customer's WhatsApp Business Account (WABA) ID.

Returns:

  • (::String)

    The customer's WhatsApp Business Account (WABA) ID.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 100

class WhatsappConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#whatsapp_business_token::String

Returns:



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1/omnichannel.rb', line 100

class WhatsappConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end