Class: Google::Cloud::Ces::V1::OpenApiToolset

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/open_api_toolset.rb

Overview

A toolset that contains a list of tools that are defined by an OpenAPI schema.

Instance Attribute Summary collapse

Instance Attribute Details

#api_authentication::Google::Cloud::Ces::V1::ApiAuthentication

Returns Optional. Authentication information required by the API.

Returns:



50
51
52
53
# File 'proto_docs/google/cloud/ces/v1/open_api_toolset.rb', line 50

class OpenApiToolset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ignore_unknown_fields::Boolean

Returns Optional. If true, the agent will ignore unknown fields in the API response for all operations defined in the OpenAPI schema.

Returns:

  • (::Boolean)

    Optional. If true, the agent will ignore unknown fields in the API response for all operations defined in the OpenAPI schema.



50
51
52
53
# File 'proto_docs/google/cloud/ces/v1/open_api_toolset.rb', line 50

class OpenApiToolset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#open_api_schema::String

Returns Required. The OpenAPI schema of the toolset.

Returns:

  • (::String)

    Required. The OpenAPI schema of the toolset.



50
51
52
53
# File 'proto_docs/google/cloud/ces/v1/open_api_toolset.rb', line 50

class OpenApiToolset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_directory_config::Google::Cloud::Ces::V1::ServiceDirectoryConfig

Returns Optional. Service Directory configuration.

Returns:



50
51
52
53
# File 'proto_docs/google/cloud/ces/v1/open_api_toolset.rb', line 50

class OpenApiToolset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tls_config::Google::Cloud::Ces::V1::TlsConfig

Returns Optional. The TLS configuration. Includes the custom server certificates.

Returns:



50
51
52
53
# File 'proto_docs/google/cloud/ces/v1/open_api_toolset.rb', line 50

class OpenApiToolset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url::String

Returns Optional. The server URL of the Open API schema. This field is only set in toolsets in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema.

Returns:

  • (::String)

    Optional. The server URL of the Open API schema. This field is only set in toolsets in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema.



50
51
52
53
# File 'proto_docs/google/cloud/ces/v1/open_api_toolset.rb', line 50

class OpenApiToolset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end