Class: Google::Cloud::Ces::V1::PythonFunction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/python_function.rb

Overview

A Python function tool.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String (readonly)

Returns Output only. The description of the Python function, parsed from the python code's docstring.

Returns:

  • (::String)

    Output only. The description of the Python function, parsed from the python code's docstring.



37
38
39
40
# File 'proto_docs/google/cloud/ces/v1/python_function.rb', line 37

class PythonFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Optional. The name of the Python function to execute. Must match a Python function name defined in the python code. Case sensitive. If the name is not provided, the first function defined in the python code will be used.

Returns:

  • (::String)

    Optional. The name of the Python function to execute. Must match a Python function name defined in the python code. Case sensitive. If the name is not provided, the first function defined in the python code will be used.



37
38
39
40
# File 'proto_docs/google/cloud/ces/v1/python_function.rb', line 37

class PythonFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#python_code::String

Returns Optional. The Python code to execute for the tool.

Returns:

  • (::String)

    Optional. The Python code to execute for the tool.



37
38
39
40
# File 'proto_docs/google/cloud/ces/v1/python_function.rb', line 37

class PythonFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end