Class: Google::Cloud::Ces::V1::RecognitionResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/session_service.rb

Overview

Speech recognition result for the audio input.

Instance Attribute Summary collapse

Instance Attribute Details

#transcript::String

Returns Optional. Concatenated user speech segments captured during the current turn.

Returns:

  • (::String)

    Optional. Concatenated user speech segments captured during the current turn.



334
335
336
337
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 334

class RecognitionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end