Class: Google::Cloud::Ces::V1::RedactionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::RedactionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/app.rb
Overview
Configuration to instruct how sensitive data should be handled.
Instance Attribute Summary collapse
-
#deidentify_template ⇒ ::String
Optional.
-
#enable_redaction ⇒ ::Boolean
Optional.
-
#inspect_template ⇒ ::String
Optional.
Instance Attribute Details
#deidentify_template ⇒ ::String
Returns Optional. DLP deidentify template name to instruct on how to de-identify content.
Format:
projects/{project}/locations/{location}/deidentifyTemplates/{deidentify_template}.
634 635 636 637 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 634 class RedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_redaction ⇒ ::Boolean
Returns Optional. If true, redaction will be applied in various logging scenarios, including conversation history, Cloud Logging and audio recording.
634 635 636 637 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 634 class RedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#inspect_template ⇒ ::String
Returns Optional. DLP inspect template name to configure detection of sensitive data types.
Format:
projects/{project}/locations/{location}/inspectTemplates/{inspect_template}.
634 635 636 637 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 634 class RedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |