Class: Google::Cloud::Ces::V1::RetrieveToolsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::RetrieveToolsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/tool_service.rb
Overview
Response message for ToolService.RetrieveTools.
Instance Attribute Summary collapse
-
#tools ⇒ ::Array<::Google::Cloud::Ces::V1::Tool>
The list of tools that are included in the specified toolset.
Instance Attribute Details
#tools ⇒ ::Array<::Google::Cloud::Ces::V1::Tool>
Returns The list of tools that are included in the specified toolset.
161 162 163 164 |
# File 'proto_docs/google/cloud/ces/v1/tool_service.rb', line 161 class RetrieveToolsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |