Class: Google::Cloud::Ces::V1::Schema

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/schema.rb

Overview

Represents a select subset of an OpenAPI 3.0 schema object.

Defined Under Namespace

Modules: Type Classes: DefsEntry, PropertiesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#additional_properties::Google::Cloud::Ces::V1::Schema

Returns Optional. Can either be a boolean or an object, controls the presence of additional properties.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#any_of::Array<::Google::Cloud::Ces::V1::Schema>

Returns Optional. The value should be validated against any (one or more) of the subschemas in the list.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#default::Google::Protobuf::Value

Returns Optional. Default value of the data.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#defs::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1::Schema}

Returns Optional. A map of definitions for use by ref. Only allowed at the root of the schema.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1::Schema})

    Optional. A map of definitions for use by ref. Only allowed at the root of the schema.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#description::String

Returns Optional. The description of the data.

Returns:

  • (::String)

    Optional. The description of the data.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#enum::Array<::String>

Returns Optional. Possible values of the element of primitive type with enum format. Examples:

  1. We can define direction as : {type:STRING, format:enum, enum:["EAST", NORTH", "SOUTH", "WEST"]}
  2. We can define apartment number as : {type:INTEGER, format:enum, enum:["101", "201", "301"]}.

Returns:

  • (::Array<::String>)

    Optional. Possible values of the element of primitive type with enum format. Examples:

    1. We can define direction as : {type:STRING, format:enum, enum:["EAST", NORTH", "SOUTH", "WEST"]}
    2. We can define apartment number as : {type:INTEGER, format:enum, enum:["101", "201", "301"]}


113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#items::Google::Cloud::Ces::V1::Schema

Returns Optional. Schema of the elements of Type.ARRAY.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#max_items::Integer

Returns Optional. Maximum number of the elements for Type.ARRAY.

Returns:

  • (::Integer)

    Optional. Maximum number of the elements for Type.ARRAY.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#maximum::Float

Returns Optional. Maximum value for Type.INTEGER and Type.NUMBER.

Returns:

  • (::Float)

    Optional. Maximum value for Type.INTEGER and Type.NUMBER.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#min_items::Integer

Returns Optional. Minimum number of the elements for Type.ARRAY.

Returns:

  • (::Integer)

    Optional. Minimum number of the elements for Type.ARRAY.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#minimum::Float

Returns Optional. Minimum value for Type.INTEGER and Type.NUMBER.

Returns:

  • (::Float)

    Optional. Minimum value for Type.INTEGER and Type.NUMBER.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#nullable::Boolean

Returns Optional. Indicates if the value may be null.

Returns:

  • (::Boolean)

    Optional. Indicates if the value may be null.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#prefix_items::Array<::Google::Cloud::Ces::V1::Schema>

Returns Optional. Schemas of initial elements of Type.ARRAY.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#properties::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1::Schema}

Returns Optional. Properties of Type.OBJECT.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#ref::String

Returns Optional. Allows indirect references between schema nodes. The value should be a valid reference to a child of the root defs.

For example, the following schema defines a reference to a schema node named "Pet":

type: object
properties:
  pet:
    ref: #/defs/Pet
defs:
  Pet:
    type: object
    properties:
      name:
        type: string

The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding-json-schema/structuring.

Returns:

  • (::String)

    Optional. Allows indirect references between schema nodes. The value should be a valid reference to a child of the root defs.

    For example, the following schema defines a reference to a schema node named "Pet":

    type: object
    properties:
      pet:
        ref: #/defs/Pet
    defs:
      Pet:
        type: object
        properties:
          name:
            type: string
    

    The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding-json-schema/structuring.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#required::Array<::String>

Returns Optional. Required properties of Type.OBJECT.

Returns:

  • (::Array<::String>)

    Optional. Required properties of Type.OBJECT.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#title::String

Returns Optional. The title of the schema.

Returns:

  • (::String)

    Optional. The title of the schema.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#type::Google::Cloud::Ces::V1::Schema::Type

Returns Required. The type of the data.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end

#unique_items::Boolean

Returns Optional. Indicate the items in the array must be unique. Only applies to TYPE.ARRAY.

Returns:

  • (::Boolean)

    Optional. Indicate the items in the array must be unique. Only applies to TYPE.ARRAY.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'proto_docs/google/cloud/ces/v1/schema.rb', line 113

class Schema
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class PropertiesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Ces::V1::Schema]
  class DefsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # OpenAPI data types.
  module Type
    # Type unspecified.
    TYPE_UNSPECIFIED = 0

    # String type.
    STRING = 1

    # Integer type.
    INTEGER = 2

    # Number type.
    NUMBER = 3

    # Boolean type.
    BOOLEAN = 4

    # Object type.
    OBJECT = 5

    # Array type.
    ARRAY = 6
  end
end