Class: Google::Cloud::Ces::V1::SessionConfig::RemoteDialogflowQueryParameters
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::SessionConfig::RemoteDialogflowQueryParameters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/session_service.rb
Overview
QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
Defined Under Namespace
Classes: WebhookHeadersEntry
Instance Attribute Summary collapse
-
#end_user_metadata ⇒ ::Google::Protobuf::Struct
Optional.
-
#payload ⇒ ::Google::Protobuf::Struct
Optional.
-
#webhook_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#end_user_metadata ⇒ ::Google::Protobuf::Struct
Returns Optional. The end user metadata to be sent in QueryParameters.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 132 class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#payload ⇒ ::Google::Protobuf::Struct
Returns Optional. The payload to be sent in QueryParameters.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 132 class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#webhook_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The HTTP headers to be sent as webhook_headers in QueryParameters.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 132 class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |