Class: Google::Cloud::Ces::V1::SynthesizeSpeechConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/app.rb

Overview

Configuration for how the agent response should be synthesized.

Instance Attribute Summary collapse

Instance Attribute Details

#speaking_rate::Float

Optional. The speaking rate/speed in the range [0.25, 2.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. Values outside of the range [0.25, 2.0] will return an error.

Returns:

  • (::Float)

    Optional. The speaking rate/speed in the range [0.25, 2.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. Values outside of the range [0.25, 2.0] will return an error.



356
357
358
359
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 356

class SynthesizeSpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#voice::String

Returns Optional. The name of the voice. If not set, the service will choose a voice based on the other parameters such as language_code.

For the list of available voices, please refer to Supported voices and languages from Cloud Text-to-Speech.

Returns:

  • (::String)

    Optional. The name of the voice. If not set, the service will choose a voice based on the other parameters such as language_code.

    For the list of available voices, please refer to Supported voices and languages from Cloud Text-to-Speech.



356
357
358
359
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 356

class SynthesizeSpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end