Class: Google::Cloud::Ces::V1::Tool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/tool.rb

Overview

A tool represents an action that the CES agent can take to achieve certain goals.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_tool::Google::Cloud::Ces::V1::AgentTool

Returns Optional. The agent tool.

Note: The following fields are mutually exclusive: agent_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::AgentTool)

    Optional. The agent tool.

    Note: The following fields are mutually exclusive: agent_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_function::Google::Cloud::Ces::V1::ClientFunction

Returns Optional. The client function.

Note: The following fields are mutually exclusive: client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::ClientFunction)

    Optional. The client function.

    Note: The following fields are mutually exclusive: client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#connector_tool::Google::Cloud::Ces::V1::ConnectorTool

Returns Optional. The Integration Connector tool.

Note: The following fields are mutually exclusive: connector_tool, client_function, open_api_tool, google_search_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::ConnectorTool)

    Optional. The Integration Connector tool.

    Note: The following fields are mutually exclusive: connector_tool, client_function, open_api_tool, google_search_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the tool was created.

Returns:



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_store_tool::Google::Cloud::Ces::V1::DataStoreTool

Returns Optional. The data store tool.

Note: The following fields are mutually exclusive: data_store_tool, client_function, open_api_tool, google_search_tool, connector_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::DataStoreTool)

    Optional. The data store tool.

    Note: The following fields are mutually exclusive: data_store_tool, client_function, open_api_tool, google_search_tool, connector_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. The display name of the tool, derived based on the tool's type. For example, display name of a [ClientFunction][Tool.ClientFunction] is derived from its name property.

Returns:

  • (::String)

    Output only. The display name of the tool, derived based on the tool's type. For example, display name of a [ClientFunction][Tool.ClientFunction] is derived from its name property.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#etag::String

Returns Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.

Returns:

  • (::String)

    Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#execution_type::Google::Cloud::Ces::V1::ExecutionType

Returns Optional. The execution type of the tool.

Returns:



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#file_search_tool::Google::Cloud::Ces::V1::FileSearchTool

Returns Optional. The file search tool.

Note: The following fields are mutually exclusive: file_search_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::FileSearchTool)

    Optional. The file search tool.

    Note: The following fields are mutually exclusive: file_search_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#generated_summary::String (readonly)

Returns Output only. If the tool is generated by the LLM assistant, this field contains a descriptive summary of the generation.

Returns:

  • (::String)

    Output only. If the tool is generated by the LLM assistant, this field contains a descriptive summary of the generation.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#google_search_tool::Google::Cloud::Ces::V1::GoogleSearchTool

Returns Optional. The google search tool.

Note: The following fields are mutually exclusive: google_search_tool, client_function, open_api_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::GoogleSearchTool)

    Optional. The google search tool.

    Note: The following fields are mutually exclusive: google_search_tool, client_function, open_api_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mcp_tool::Google::Cloud::Ces::V1::McpTool

Returns Optional. The MCP tool. An MCP tool cannot be created or updated directly and is managed by the MCP toolset.

Note: The following fields are mutually exclusive: mcp_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::McpTool)

    Optional. The MCP tool. An MCP tool cannot be created or updated directly and is managed by the MCP toolset.

    Note: The following fields are mutually exclusive: mcp_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the tool. Format:

  • projects/{project}/locations/{location}/apps/{app}/tools/{tool} for standalone tools.
  • projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}/tools/{tool} for tools retrieved from a toolset.

These tools are dynamic and output-only; they cannot be referenced directly where a tool is expected.

Returns:

  • (::String)

    Identifier. The resource name of the tool. Format:

    • projects/{project}/locations/{location}/apps/{app}/tools/{tool} for standalone tools.
    • projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}/tools/{tool} for tools retrieved from a toolset.

    These tools are dynamic and output-only; they cannot be referenced directly where a tool is expected.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#open_api_tool::Google::Cloud::Ces::V1::OpenApiTool

Returns Optional. The open API tool.

Note: The following fields are mutually exclusive: open_api_tool, client_function, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::OpenApiTool)

    Optional. The open API tool.

    Note: The following fields are mutually exclusive: open_api_tool, client_function, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#python_function::Google::Cloud::Ces::V1::PythonFunction

Returns Optional. The python function tool.

Note: The following fields are mutually exclusive: python_function, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::PythonFunction)

    Optional. The python function tool.

    Note: The following fields are mutually exclusive: python_function, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, mcp_tool, file_search_tool, system_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#system_tool::Google::Cloud::Ces::V1::SystemTool

Returns Optional. The system tool.

Note: The following fields are mutually exclusive: system_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::SystemTool)

    Optional. The system tool.

    Note: The following fields are mutually exclusive: system_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, agent_tool, widget_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool_fake_config::Google::Cloud::Ces::V1::ToolFakeConfig

Returns Optional. Configuration for tool behavior in fake mode.

Returns:



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the tool was last updated.

Returns:



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#widget_tool::Google::Cloud::Ces::V1::WidgetTool

Returns Optional. The widget tool.

Note: The following fields are mutually exclusive: widget_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1::WidgetTool)

    Optional. The widget tool.

    Note: The following fields are mutually exclusive: widget_tool, client_function, open_api_tool, google_search_tool, connector_tool, data_store_tool, python_function, mcp_tool, file_search_tool, system_tool, agent_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



119
120
121
122
# File 'proto_docs/google/cloud/ces/v1/tool.rb', line 119

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end