Class: Google::Cloud::Ces::V1::ToolCall
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ToolCall
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/example.rb
Overview
Request for the client or the agent to execute the specified tool.
Instance Attribute Summary collapse
-
#args ⇒ ::Google::Protobuf::Struct
Optional.
-
#display_name ⇒ ::String
readonly
Output only.
-
#id ⇒ ::String
Optional.
-
#tool ⇒ ::String
Optional.
-
#toolset_tool ⇒ ::Google::Cloud::Ces::V1::ToolsetTool
Optional.
Instance Attribute Details
#args ⇒ ::Google::Protobuf::Struct
Returns Optional. The input parameters and values for the tool in JSON object format.
192 193 194 195 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 192 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String (readonly)
Returns Output only. Display name of the tool.
192 193 194 195 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 192 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns Optional. The unique identifier of the tool call. If populated, the client should return the execution result with the matching ID in ToolResponse.
192 193 194 195 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 192 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String
Returns Optional. The name of the tool to execute.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
192 193 194 195 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 192 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_tool ⇒ ::Google::Cloud::Ces::V1::ToolsetTool
Returns Optional. The toolset tool to execute.
Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
192 193 194 195 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 192 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |