Class: Google::Cloud::Ces::V1::ToolCalls

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/session_service.rb

Overview

Request for the client to execute the tools and return the execution results before continuing the session.

Instance Attribute Summary collapse

Instance Attribute Details

#tool_calls::Array<::Google::Cloud::Ces::V1::ToolCall>

Returns Optional. The list of tool calls to execute.

Returns:



152
153
154
155
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 152

class ToolCalls
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end