Class: Google::Cloud::Ces::V1::ToolService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ToolService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/ces/v1/tool_service/rest/client.rb
Overview
REST client for the ToolService service.
Tool service provides APIs for interacting with CES tools.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ToolService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ToolService Client instance.
-
#execute_tool(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Ces::V1::ExecuteToolResponse
Executes the given tool with the given arguments.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ToolService REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#retrieve_tool_schema(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Ces::V1::RetrieveToolSchemaResponse
Retrieve the schema of the given tool.
-
#retrieve_tools(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Ces::V1::RetrieveToolsResponse
Retrieve the list of tools included in the specified toolset.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#app_path, #tool_path, #toolset_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ToolService REST client object.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 132 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @tool_service_stub = ::Google::Cloud::Ces::V1::ToolService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @tool_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @tool_service_stub.endpoint config.universe_domain = @tool_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @tool_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
188 189 190 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 188 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ToolService Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Ces", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the ToolService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
102 103 104 105 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 102 def configure yield @config if block_given? @config end |
#execute_tool(request, options = nil) ⇒ ::Google::Cloud::Ces::V1::ExecuteToolResponse #execute_tool(tool: nil, toolset_tool: nil, variables: nil, context: nil, parent: nil, args: nil) ⇒ ::Google::Cloud::Ces::V1::ExecuteToolResponse
Executes the given tool with the given arguments.
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 269 def execute_tool request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1::ExecuteToolRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.execute_tool..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.execute_tool.timeout, metadata: , retry_policy: @config.rpcs.execute_tool.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tool_service_stub.execute_tool request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
195 196 197 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 195 def logger @tool_service_stub.logger end |
#retrieve_tool_schema(request, options = nil) ⇒ ::Google::Cloud::Ces::V1::RetrieveToolSchemaResponse #retrieve_tool_schema(tool: nil, toolset_tool: nil, parent: nil) ⇒ ::Google::Cloud::Ces::V1::RetrieveToolSchemaResponse
Retrieve the schema of the given tool. The schema is computed on the fly for the given instance of the tool.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 361 def retrieve_tool_schema request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1::RetrieveToolSchemaRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.retrieve_tool_schema..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.retrieve_tool_schema.timeout, metadata: , retry_policy: @config.rpcs.retrieve_tool_schema.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tool_service_stub.retrieve_tool_schema request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#retrieve_tools(request, options = nil) ⇒ ::Google::Cloud::Ces::V1::RetrieveToolsResponse #retrieve_tools(toolset: nil, tool_ids: nil) ⇒ ::Google::Cloud::Ces::V1::RetrieveToolsResponse
Retrieve the list of tools included in the specified toolset.
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 444 def retrieve_tools request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1::RetrieveToolsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.retrieve_tools..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.retrieve_tools.timeout, metadata: , retry_policy: @config.rpcs.retrieve_tools.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @tool_service_stub.retrieve_tools request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
112 113 114 |
# File 'lib/google/cloud/ces/v1/tool_service/rest/client.rb', line 112 def universe_domain @tool_service_stub.universe_domain end |