Class: Google::Cloud::Ces::V1::ToolsetTool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/toolset_tool.rb

Overview

A tool that is created from a toolset.

Instance Attribute Summary collapse

Instance Attribute Details

#tool_id::String

Returns Optional. The tool ID to filter the tools to retrieve the schema for.

Returns:

  • (::String)

    Optional. The tool ID to filter the tools to retrieve the schema for.



33
34
35
36
# File 'proto_docs/google/cloud/ces/v1/toolset_tool.rb', line 33

class ToolsetTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#toolset::String

Returns Required. The resource name of the Toolset from which this tool is derived. Format: projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}.

Returns:

  • (::String)

    Required. The resource name of the Toolset from which this tool is derived. Format: projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}



33
34
35
36
# File 'proto_docs/google/cloud/ces/v1/toolset_tool.rb', line 33

class ToolsetTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end