Module: Google::Cloud::Ces::V1::TransferRule::Direction
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_transfers.rb
Overview
The direction of the transfer.
Constant Summary collapse
- DIRECTION_UNSPECIFIED =
Unspecified direction.
0- PARENT_TO_CHILD =
Transfer from the parent agent to the child agent.
1- CHILD_TO_PARENT =
Transfer from the child agent to the parent agent.
2