Class: Google::Cloud::Ces::V1::TriggerAction
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::TriggerAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/common.rb
Overview
Action that is taken when a certain precondition is met.
Defined Under Namespace
Classes: GenerativeAnswer, RespondImmediately, Response, TransferAgent
Instance Attribute Summary collapse
-
#generative_answer ⇒ ::Google::Cloud::Ces::V1::TriggerAction::GenerativeAnswer
Optional.
-
#respond_immediately ⇒ ::Google::Cloud::Ces::V1::TriggerAction::RespondImmediately
Optional.
-
#transfer_agent ⇒ ::Google::Cloud::Ces::V1::TriggerAction::TransferAgent
Optional.
Instance Attribute Details
#generative_answer ⇒ ::Google::Cloud::Ces::V1::TriggerAction::GenerativeAnswer
Returns Optional. Respond with a generative answer.
Note: The following fields are mutually exclusive: generative_answer, respond_immediately, transfer_agent. If a field in that set is populated, all other fields in the set will automatically be cleared.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 81 class TriggerAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a response from the agent. # @!attribute [rw] text # @return [::String] # Required. Text for the agent to respond with. # @!attribute [rw] disabled # @return [::Boolean] # Optional. Whether the response is disabled. Disabled responses are not # used by the agent. class Response include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will immediately respond with a preconfigured response. # @!attribute [rw] responses # @return [::Array<::Google::Cloud::Ces::V1::TriggerAction::Response>] # Required. The canned responses for the agent to choose from. The response # is chosen randomly. class RespondImmediately include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will immediately respond with a generative answer. # @!attribute [rw] prompt # @return [::String] # Required. The prompt to use for the generative answer. class GenerativeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will transfer the conversation to a different agent. # @!attribute [rw] agent # @return [::String] # Required. The name of the agent to transfer the conversation to. The # agent must be in the same app as the current agent. Format: # `projects/{project}/locations/{location}/apps/{app}/agents/{agent}` class TransferAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#respond_immediately ⇒ ::Google::Cloud::Ces::V1::TriggerAction::RespondImmediately
Returns Optional. Immediately respond with a preconfigured response.
Note: The following fields are mutually exclusive: respond_immediately, transfer_agent, generative_answer. If a field in that set is populated, all other fields in the set will automatically be cleared.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 81 class TriggerAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a response from the agent. # @!attribute [rw] text # @return [::String] # Required. Text for the agent to respond with. # @!attribute [rw] disabled # @return [::Boolean] # Optional. Whether the response is disabled. Disabled responses are not # used by the agent. class Response include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will immediately respond with a preconfigured response. # @!attribute [rw] responses # @return [::Array<::Google::Cloud::Ces::V1::TriggerAction::Response>] # Required. The canned responses for the agent to choose from. The response # is chosen randomly. class RespondImmediately include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will immediately respond with a generative answer. # @!attribute [rw] prompt # @return [::String] # Required. The prompt to use for the generative answer. class GenerativeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will transfer the conversation to a different agent. # @!attribute [rw] agent # @return [::String] # Required. The name of the agent to transfer the conversation to. The # agent must be in the same app as the current agent. Format: # `projects/{project}/locations/{location}/apps/{app}/agents/{agent}` class TransferAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#transfer_agent ⇒ ::Google::Cloud::Ces::V1::TriggerAction::TransferAgent
Returns Optional. Transfer the conversation to a different agent.
Note: The following fields are mutually exclusive: transfer_agent, respond_immediately, generative_answer. If a field in that set is populated, all other fields in the set will automatically be cleared.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 81 class TriggerAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a response from the agent. # @!attribute [rw] text # @return [::String] # Required. Text for the agent to respond with. # @!attribute [rw] disabled # @return [::Boolean] # Optional. Whether the response is disabled. Disabled responses are not # used by the agent. class Response include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will immediately respond with a preconfigured response. # @!attribute [rw] responses # @return [::Array<::Google::Cloud::Ces::V1::TriggerAction::Response>] # Required. The canned responses for the agent to choose from. The response # is chosen randomly. class RespondImmediately include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will immediately respond with a generative answer. # @!attribute [rw] prompt # @return [::String] # Required. The prompt to use for the generative answer. class GenerativeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The agent will transfer the conversation to a different agent. # @!attribute [rw] agent # @return [::String] # Required. The name of the agent to transfer the conversation to. The # agent must be in the same app as the current agent. Format: # `projects/{project}/locations/{location}/apps/{app}/agents/{agent}` class TransferAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |