Class: Google::Cloud::Ces::V1::TriggerAction::TransferAgent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/common.rb

Overview

The agent will transfer the conversation to a different agent.

Instance Attribute Summary collapse

Instance Attribute Details

#agent::String

Returns Required. The name of the agent to transfer the conversation to. The agent must be in the same app as the current agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.

Returns:

  • (::String)

    Required. The name of the agent to transfer the conversation to. The agent must be in the same app as the current agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}



123
124
125
126
# File 'proto_docs/google/cloud/ces/v1/common.rb', line 123

class TransferAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end