Class: Google::Cloud::Ces::V1::UpdateExampleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::UpdateExampleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.UpdateExample.
Instance Attribute Summary collapse
-
#example ⇒ ::Google::Cloud::Ces::V1::Example
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#example ⇒ ::Google::Cloud::Ces::V1::Example
Returns Required. The example to update.
500 501 502 503 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 500 class UpdateExampleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
500 501 502 503 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 500 class UpdateExampleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |