Class: Google::Cloud::Ces::V1::UpdateGuardrailRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.UpdateGuardrail.

Instance Attribute Summary collapse

Instance Attribute Details

#guardrail::Google::Cloud::Ces::V1::Guardrail

Returns Required. The guardrail to update.

Returns:



826
827
828
829
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 826

class UpdateGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



826
827
828
829
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 826

class UpdateGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end