Class: Google::Cloud::Ces::V1::UpdateToolRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::UpdateToolRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.UpdateTool.
Instance Attribute Summary collapse
-
#tool ⇒ ::Google::Cloud::Ces::V1::Tool
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#tool ⇒ ::Google::Cloud::Ces::V1::Tool
Returns Required. The tool to update.
603 604 605 606 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 603 class UpdateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
603 604 605 606 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 603 class UpdateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |