Class: Google::Cloud::Ces::V1::UpdateToolsetRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/agent_service.rb

Overview

Request message for AgentService.UpdateToolset.

Instance Attribute Summary collapse

Instance Attribute Details

#toolset::Google::Cloud::Ces::V1::Toolset

Returns Required. The toolset to update.

Returns:



1043
1044
1045
1046
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1043

class UpdateToolsetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



1043
1044
1045
1046
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1043

class UpdateToolsetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end