Class: Google::Cloud::Ces::V1::WebSearchQuery

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1/search_suggestions.rb

Overview

Represents a single web search query and its associated search uri.

Instance Attribute Summary collapse

Instance Attribute Details

#query::String

Returns The search query text.

Returns:

  • (::String)

    The search query text.



48
49
50
51
# File 'proto_docs/google/cloud/ces/v1/search_suggestions.rb', line 48

class WebSearchQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String

Returns The URI to the Google Search results page for the query.

Returns:

  • (::String)

    The URI to the Google Search results page for the query.



48
49
50
51
# File 'proto_docs/google/cloud/ces/v1/search_suggestions.rb', line 48

class WebSearchQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end