Class: Google::Cloud::Ces::V1::WidgetTool::DataMapping
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::WidgetTool::DataMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/widget_tool.rb
Overview
Configuration for mapping data from a source tool to the widget's input parameters.
Defined Under Namespace
Modules: Mode Classes: FieldMappingsEntry
Instance Attribute Summary collapse
-
#field_mappings ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#mode ⇒ ::Google::Cloud::Ces::V1::WidgetTool::DataMapping::Mode
Optional.
-
#python_function ⇒ ::Google::Cloud::Ces::V1::PythonFunction
Optional.
-
#python_script ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#source_tool_name ⇒ ::String
Optional.
Instance Attribute Details
#field_mappings ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. A map of widget input parameter fields to the corresponding output fields of the source tool.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/widget_tool.rb', line 74 class DataMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FieldMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The strategy used to map data from the source tool to the widget. module Mode # Unspecified mode. MODE_UNSPECIFIED = 0 # Use the `field_mappings` map for data transformation. FIELD_MAPPING = 1 # Use the `python_script` for data transformation. PYTHON_SCRIPT = 2 end end |
#mode ⇒ ::Google::Cloud::Ces::V1::WidgetTool::DataMapping::Mode
Returns Optional. The mode of the data mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/widget_tool.rb', line 74 class DataMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FieldMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The strategy used to map data from the source tool to the widget. module Mode # Unspecified mode. MODE_UNSPECIFIED = 0 # Use the `field_mappings` map for data transformation. FIELD_MAPPING = 1 # Use the `python_script` for data transformation. PYTHON_SCRIPT = 2 end end |
#python_function ⇒ ::Google::Cloud::Ces::V1::PythonFunction
Returns Optional. Configuration for a Python function used to transform the source tool's output into the widget's input format.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/widget_tool.rb', line 74 class DataMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FieldMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The strategy used to map data from the source tool to the widget. module Mode # Unspecified mode. MODE_UNSPECIFIED = 0 # Use the `field_mappings` map for data transformation. FIELD_MAPPING = 1 # Use the `python_script` for data transformation. PYTHON_SCRIPT = 2 end end |
#python_script ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated: Use python_function instead.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/widget_tool.rb', line 74 class DataMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FieldMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The strategy used to map data from the source tool to the widget. module Mode # Unspecified mode. MODE_UNSPECIFIED = 0 # Use the `field_mappings` map for data transformation. FIELD_MAPPING = 1 # Use the `python_script` for data transformation. PYTHON_SCRIPT = 2 end end |
#source_tool_name ⇒ ::String
Returns Optional. The resource name of the tool that provides the data for the
widget (e.g., a search tool or a custom function). Format:
projects/{project}/locations/{location}/agents/{agent}/tools/{tool}.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/widget_tool.rb', line 74 class DataMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FieldMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The strategy used to map data from the source tool to the widget. module Mode # Unspecified mode. MODE_UNSPECIFIED = 0 # Use the `field_mappings` map for data transformation. FIELD_MAPPING = 1 # Use the `python_script` for data transformation. PYTHON_SCRIPT = 2 end end |