Class: Google::Cloud::Ces::V1::AgentTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::AgentTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_tool.rb
Overview
Represents a tool that allows the agent to call another agent.
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#root_agent ⇒ ::String
Optional.
Instance Attribute Details
#description ⇒ ::String
Returns Optional. Description of the tool's purpose.
35 36 37 38 |
# File 'proto_docs/google/cloud/ces/v1/agent_tool.rb', line 35 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the agent tool.
35 36 37 38 |
# File 'proto_docs/google/cloud/ces/v1/agent_tool.rb', line 35 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#root_agent ⇒ ::String
Returns Optional. The resource name of the root agent that is the entry point of
the tool. Format: projects/{project}/locations/{location}/agents/{agent}.
35 36 37 38 |
# File 'proto_docs/google/cloud/ces/v1/agent_tool.rb', line 35 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |