Class: Google::Cloud::Ces::V1::Chunk
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::Chunk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/example.rb
Overview
A chunk of content within a message.
Instance Attribute Summary collapse
-
#agent_transfer ⇒ ::Google::Cloud::Ces::V1::AgentTransfer
Optional.
-
#blob ⇒ ::Google::Cloud::Ces::V1::Blob
Optional.
-
#default_variables ⇒ ::Google::Protobuf::Struct
A struct represents default variables at the start of the conversation, keyed by variable names.
-
#image ⇒ ::Google::Cloud::Ces::V1::Image
Optional.
-
#payload ⇒ ::Google::Protobuf::Struct
Optional.
-
#text ⇒ ::String
Optional.
-
#tool_call ⇒ ::Google::Cloud::Ces::V1::ToolCall
Optional.
-
#tool_response ⇒ ::Google::Cloud::Ces::V1::ToolResponse
Optional.
-
#transcript ⇒ ::String
Optional.
-
#updated_variables ⇒ ::Google::Protobuf::Struct
A struct represents variables that were updated in the conversation, keyed by variable names.
Instance Attribute Details
#agent_transfer ⇒ ::Google::Cloud::Ces::V1::AgentTransfer
Returns Optional. Agent transfer event.
Note: The following fields are mutually exclusive: agent_transfer, text, transcript, blob, payload, image, tool_call, tool_response, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#blob ⇒ ::Google::Cloud::Ces::V1::Blob
Returns Optional. Blob data.
Note: The following fields are mutually exclusive: blob, text, transcript, payload, image, tool_call, tool_response, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#default_variables ⇒ ::Google::Protobuf::Struct
Returns A struct represents default variables at the start of the conversation, keyed by variable names.
Note: The following fields are mutually exclusive: default_variables, text, transcript, blob, payload, image, tool_call, tool_response, agent_transfer, updated_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image ⇒ ::Google::Cloud::Ces::V1::Image
Returns Optional. Image data.
Note: The following fields are mutually exclusive: image, text, transcript, blob, payload, tool_call, tool_response, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#payload ⇒ ::Google::Protobuf::Struct
Returns Optional. Custom payload data.
Note: The following fields are mutually exclusive: payload, text, transcript, blob, image, tool_call, tool_response, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::String
Returns Optional. Text data.
Note: The following fields are mutually exclusive: text, transcript, blob, payload, image, tool_call, tool_response, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_call ⇒ ::Google::Cloud::Ces::V1::ToolCall
Returns Optional. Tool execution request.
Note: The following fields are mutually exclusive: tool_call, text, transcript, blob, payload, image, tool_response, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_response ⇒ ::Google::Cloud::Ces::V1::ToolResponse
Returns Optional. Tool execution response.
Note: The following fields are mutually exclusive: tool_response, text, transcript, blob, payload, image, tool_call, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transcript ⇒ ::String
Returns Optional. Transcript associated with the audio.
Note: The following fields are mutually exclusive: transcript, text, blob, payload, image, tool_call, tool_response, agent_transfer, updated_variables, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#updated_variables ⇒ ::Google::Protobuf::Struct
Returns A struct represents variables that were updated in the conversation, keyed by variable names.
Note: The following fields are mutually exclusive: updated_variables, text, transcript, blob, payload, image, tool_call, tool_response, agent_transfer, default_variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 135 class Chunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |