Class: Google::Cloud::Ces::V1::ConnectorTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ConnectorTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/connector_tool.rb
Overview
A ConnectorTool allows connections to different integrations. See: https://cloud.google.com/integration-connectors/docs/overview.
Instance Attribute Summary collapse
-
#action ⇒ ::Google::Cloud::Ces::V1::Action
Required.
-
#auth_config ⇒ ::Google::Cloud::Ces::V1::EndUserAuthConfig
Optional.
-
#connection ⇒ ::String
Required.
-
#description ⇒ ::String
Optional.
-
#name ⇒ ::String
Optional.
Instance Attribute Details
#action ⇒ ::Google::Cloud::Ces::V1::Action
Returns Required. Action for the tool to use.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1/connector_tool.rb', line 115 class ConnectorTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auth_config ⇒ ::Google::Cloud::Ces::V1::EndUserAuthConfig
Returns Optional. Configures how authentication is handled in Integration Connectors. By default, an admin authentication is passed in the Integration Connectors API requests. You can override it with a different end-user authentication config. Note: The Connection must have authentication override enabled in order to specify an EUC configuration here - otherwise, the ConnectorTool creation will fail. See https://cloud.google.com/application-integration/docs/configure-connectors-task#configure-authentication-override for details.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1/connector_tool.rb', line 115 class ConnectorTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#connection ⇒ ::String
Returns Required. The full resource name of the referenced Integration Connectors
Connection.
Format:
projects/{project}/locations/{location}/connections/{connection}.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1/connector_tool.rb', line 115 class ConnectorTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. The description of the tool that can be used by the Agent to decide whether to call this ConnectorTool.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1/connector_tool.rb', line 115 class ConnectorTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Optional. The name of the tool that can be used by the Agent to decide whether to call this ConnectorTool.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1/connector_tool.rb', line 115 class ConnectorTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |