Class: Google::Cloud::Ces::V1::ConnectorToolset
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ConnectorToolset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/connector_toolset.rb
Overview
A toolset that generates tools from an Integration Connectors Connection.
Instance Attribute Summary collapse
-
#auth_config ⇒ ::Google::Cloud::Ces::V1::EndUserAuthConfig
Optional.
-
#connection ⇒ ::String
Required.
-
#connector_actions ⇒ ::Array<::Google::Cloud::Ces::V1::Action>
Required.
Instance Attribute Details
#auth_config ⇒ ::Google::Cloud::Ces::V1::EndUserAuthConfig
Returns Optional. Configures how authentication is handled in Integration Connectors. By default, an admin authentication is passed in the Integration Connectors API requests. You can override it with a different end-user authentication config. Note: The Connection must have authentication override enabled in order to specify an EUC configuration here - otherwise, the Toolset creation will fail. See: https://cloud.google.com/application-integration/docs/configure-connectors-task#configure-authentication-override.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1/connector_toolset.rb', line 45 class ConnectorToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#connection ⇒ ::String
Returns Required. The full resource name of the referenced Integration Connectors
Connection.
Format:
projects/{project}/locations/{location}/connections/{connection}.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1/connector_toolset.rb', line 45 class ConnectorToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#connector_actions ⇒ ::Array<::Google::Cloud::Ces::V1::Action>
Returns Required. The list of connector actions/entity operations to generate tools for.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1/connector_toolset.rb', line 45 class ConnectorToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |