Class: Google::Cloud::Ces::V1::CreateAppRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::CreateAppRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.CreateApp.
Instance Attribute Summary collapse
-
#app ⇒ ::Google::Cloud::Ces::V1::App
Required.
-
#app_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#app ⇒ ::Google::Cloud::Ces::V1::App
Returns Required. The app to create.
94 95 96 97 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 94 class CreateAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#app_id ⇒ ::String
Returns Optional. The ID to use for the app, which will become the final component of the app's resource name. If not provided, a unique ID will be automatically assigned for the app.
94 95 96 97 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 94 class CreateAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the location to create an app in.
94 95 96 97 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 94 class CreateAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |