Class: Google::Cloud::Ces::V1::DataStore
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::DataStore
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/data_store.rb
Overview
A DataStore resource in Vertex AI Search.
Defined Under Namespace
Modules: DataStoreType, DocumentProcessingMode Classes: ConnectorConfig
Instance Attribute Summary collapse
-
#connector_config ⇒ ::Google::Cloud::Ces::V1::DataStore::ConnectorConfig
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#document_processing_mode ⇒ ::Google::Cloud::Ces::V1::DataStore::DocumentProcessingMode
readonly
Output only.
-
#name ⇒ ::String
Required.
-
#type ⇒ ::Google::Cloud::Ces::V1::DataStore::DataStoreType
readonly
Output only.
Instance Attribute Details
#connector_config ⇒ ::Google::Cloud::Ces::V1::DataStore::ConnectorConfig (readonly)
Returns Output only. The connector config for the data store connection.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 47 class DataStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connector config for the data store connection. # @!attribute [rw] collection # @return [::String] # Resource name of the collection the data store belongs to. # @!attribute [rw] collection_display_name # @return [::String] # Display name of the collection the data store belongs to. # @!attribute [rw] data_source # @return [::String] # The name of the data source. # Example: `salesforce`, `jira`, `confluence`, `bigquery`. class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the data store. module DataStoreType # Not specified. This value indicates that the data store type is not # specified, so it will not be used during search. DATA_STORE_TYPE_UNSPECIFIED = 0 # A data store that contains public web content. PUBLIC_WEB = 1 # A data store that contains unstructured private data. UNSTRUCTURED = 2 # A data store that contains structured data used as FAQ. FAQ = 3 # A data store that is a connector to a first-party or a third-party # service. CONNECTOR = 4 end # The document processing mode of the data store. module DocumentProcessingMode # Not specified. DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0 # Documents are processed as documents. DOCUMENTS = 1 # Documents are converted to chunks. CHUNKS = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the data store was created.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 47 class DataStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connector config for the data store connection. # @!attribute [rw] collection # @return [::String] # Resource name of the collection the data store belongs to. # @!attribute [rw] collection_display_name # @return [::String] # Display name of the collection the data store belongs to. # @!attribute [rw] data_source # @return [::String] # The name of the data source. # Example: `salesforce`, `jira`, `confluence`, `bigquery`. class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the data store. module DataStoreType # Not specified. This value indicates that the data store type is not # specified, so it will not be used during search. DATA_STORE_TYPE_UNSPECIFIED = 0 # A data store that contains public web content. PUBLIC_WEB = 1 # A data store that contains unstructured private data. UNSTRUCTURED = 2 # A data store that contains structured data used as FAQ. FAQ = 3 # A data store that is a connector to a first-party or a third-party # service. CONNECTOR = 4 end # The document processing mode of the data store. module DocumentProcessingMode # Not specified. DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0 # Documents are processed as documents. DOCUMENTS = 1 # Documents are converted to chunks. CHUNKS = 2 end end |
#display_name ⇒ ::String (readonly)
Returns Output only. The display name of the data store.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 47 class DataStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connector config for the data store connection. # @!attribute [rw] collection # @return [::String] # Resource name of the collection the data store belongs to. # @!attribute [rw] collection_display_name # @return [::String] # Display name of the collection the data store belongs to. # @!attribute [rw] data_source # @return [::String] # The name of the data source. # Example: `salesforce`, `jira`, `confluence`, `bigquery`. class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the data store. module DataStoreType # Not specified. This value indicates that the data store type is not # specified, so it will not be used during search. DATA_STORE_TYPE_UNSPECIFIED = 0 # A data store that contains public web content. PUBLIC_WEB = 1 # A data store that contains unstructured private data. UNSTRUCTURED = 2 # A data store that contains structured data used as FAQ. FAQ = 3 # A data store that is a connector to a first-party or a third-party # service. CONNECTOR = 4 end # The document processing mode of the data store. module DocumentProcessingMode # Not specified. DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0 # Documents are processed as documents. DOCUMENTS = 1 # Documents are converted to chunks. CHUNKS = 2 end end |
#document_processing_mode ⇒ ::Google::Cloud::Ces::V1::DataStore::DocumentProcessingMode (readonly)
Returns Output only. The document processing mode for the data store connection. Only set for PUBLIC_WEB and UNSTRUCTURED data stores.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 47 class DataStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connector config for the data store connection. # @!attribute [rw] collection # @return [::String] # Resource name of the collection the data store belongs to. # @!attribute [rw] collection_display_name # @return [::String] # Display name of the collection the data store belongs to. # @!attribute [rw] data_source # @return [::String] # The name of the data source. # Example: `salesforce`, `jira`, `confluence`, `bigquery`. class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the data store. module DataStoreType # Not specified. This value indicates that the data store type is not # specified, so it will not be used during search. DATA_STORE_TYPE_UNSPECIFIED = 0 # A data store that contains public web content. PUBLIC_WEB = 1 # A data store that contains unstructured private data. UNSTRUCTURED = 2 # A data store that contains structured data used as FAQ. FAQ = 3 # A data store that is a connector to a first-party or a third-party # service. CONNECTOR = 4 end # The document processing mode of the data store. module DocumentProcessingMode # Not specified. DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0 # Documents are processed as documents. DOCUMENTS = 1 # Documents are converted to chunks. CHUNKS = 2 end end |
#name ⇒ ::String
Returns Required. Full resource name of the DataStore.
Format:
projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 47 class DataStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connector config for the data store connection. # @!attribute [rw] collection # @return [::String] # Resource name of the collection the data store belongs to. # @!attribute [rw] collection_display_name # @return [::String] # Display name of the collection the data store belongs to. # @!attribute [rw] data_source # @return [::String] # The name of the data source. # Example: `salesforce`, `jira`, `confluence`, `bigquery`. class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the data store. module DataStoreType # Not specified. This value indicates that the data store type is not # specified, so it will not be used during search. DATA_STORE_TYPE_UNSPECIFIED = 0 # A data store that contains public web content. PUBLIC_WEB = 1 # A data store that contains unstructured private data. UNSTRUCTURED = 2 # A data store that contains structured data used as FAQ. FAQ = 3 # A data store that is a connector to a first-party or a third-party # service. CONNECTOR = 4 end # The document processing mode of the data store. module DocumentProcessingMode # Not specified. DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0 # Documents are processed as documents. DOCUMENTS = 1 # Documents are converted to chunks. CHUNKS = 2 end end |
#type ⇒ ::Google::Cloud::Ces::V1::DataStore::DataStoreType (readonly)
Returns Output only. The type of the data store. This field is readonly and populated by the server.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/ces/v1/data_store.rb', line 47 class DataStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The connector config for the data store connection. # @!attribute [rw] collection # @return [::String] # Resource name of the collection the data store belongs to. # @!attribute [rw] collection_display_name # @return [::String] # Display name of the collection the data store belongs to. # @!attribute [rw] data_source # @return [::String] # The name of the data source. # Example: `salesforce`, `jira`, `confluence`, `bigquery`. class ConnectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the data store. module DataStoreType # Not specified. This value indicates that the data store type is not # specified, so it will not be used during search. DATA_STORE_TYPE_UNSPECIFIED = 0 # A data store that contains public web content. PUBLIC_WEB = 1 # A data store that contains unstructured private data. UNSTRUCTURED = 2 # A data store that contains structured data used as FAQ. FAQ = 3 # A data store that is a connector to a first-party or a third-party # service. CONNECTOR = 4 end # The document processing mode of the data store. module DocumentProcessingMode # Not specified. DOCUMENT_PROCESSING_MODE_UNSPECIFIED = 0 # Documents are processed as documents. DOCUMENTS = 1 # Documents are converted to chunks. CHUNKS = 2 end end |