Class: Google::Cloud::Ces::V1::DeleteAppVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::DeleteAppVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.DeleteAppVersion.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the app version. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the app version, deletion will be blocked and an ABORTED error will be returned.
1139 1140 1141 1142 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1139 class DeleteAppVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the app version to delete.
1139 1140 1141 1142 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 1139 class DeleteAppVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |