Class: Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/app.rb
Overview
Settings for golden evaluations.
Defined Under Namespace
Classes: ExpectationLevelMetricsThresholds, TurnLevelMetricsThresholds
Instance Attribute Summary collapse
-
#expectation_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds
Optional.
-
#tool_matching_settings ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::ToolMatchingSettings
Optional.
-
#turn_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds
Optional.
Instance Attribute Details
#expectation_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds
Returns Optional. The expectation level metrics thresholds.
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 462 class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tool_matching_settings ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::ToolMatchingSettings
Returns Optional. The tool matching settings. An extra tool call is a tool call that is present in the execution but does not match any tool call in the golden expectation.
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 462 class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#turn_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds
Returns Optional. The turn level metrics thresholds.
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'proto_docs/google/cloud/ces/v1/app.rb', line 462 class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |