Class: Google::Cloud::Ces::V1::GoogleSearchTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::GoogleSearchTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/google_search_tool.rb
Overview
Represents a tool to perform Google web searches for grounding. See https://cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool#google-search.
Defined Under Namespace
Classes: PromptConfig
Instance Attribute Summary collapse
-
#context_urls ⇒ ::Array<::String>
Optional.
-
#description ⇒ ::String
Optional.
-
#exclude_domains ⇒ ::Array<::String>
Optional.
-
#name ⇒ ::String
Required.
-
#preferred_domains ⇒ ::Array<::String>
Optional.
-
#prompt_config ⇒ ::Google::Cloud::Ces::V1::GoogleSearchTool::PromptConfig
Optional.
Instance Attribute Details
#context_urls ⇒ ::Array<::String>
Returns Optional. Content will be fetched directly from these URLs for context and grounding. Example: "https://example.com/path.html". A maximum of 20 URLs are allowed.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'proto_docs/google/cloud/ces/v1/google_search_tool.rb', line 52 class GoogleSearchTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Prompt settings used by the model when processing or summarizing the # google search results. # @!attribute [rw] text_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in chat conversations. If not set, default # prompt will be used. # @!attribute [rw] voice_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in voice conversations. If not set, default # prompt will be used. class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. Description of the tool's purpose.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'proto_docs/google/cloud/ces/v1/google_search_tool.rb', line 52 class GoogleSearchTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Prompt settings used by the model when processing or summarizing the # google search results. # @!attribute [rw] text_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in chat conversations. If not set, default # prompt will be used. # @!attribute [rw] voice_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in voice conversations. If not set, default # prompt will be used. class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#exclude_domains ⇒ ::Array<::String>
Returns Optional. List of domains to be excluded from the search results. Example: "example.com". A maximum of 2000 domains can be excluded.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'proto_docs/google/cloud/ces/v1/google_search_tool.rb', line 52 class GoogleSearchTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Prompt settings used by the model when processing or summarizing the # google search results. # @!attribute [rw] text_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in chat conversations. If not set, default # prompt will be used. # @!attribute [rw] voice_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in voice conversations. If not set, default # prompt will be used. class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The name of the tool.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'proto_docs/google/cloud/ces/v1/google_search_tool.rb', line 52 class GoogleSearchTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Prompt settings used by the model when processing or summarizing the # google search results. # @!attribute [rw] text_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in chat conversations. If not set, default # prompt will be used. # @!attribute [rw] voice_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in voice conversations. If not set, default # prompt will be used. class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#preferred_domains ⇒ ::Array<::String>
Returns Optional. Specifies domains to restrict search results to. Example: "example.com", "another.site". A maximum of 20 domains can be specified.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'proto_docs/google/cloud/ces/v1/google_search_tool.rb', line 52 class GoogleSearchTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Prompt settings used by the model when processing or summarizing the # google search results. # @!attribute [rw] text_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in chat conversations. If not set, default # prompt will be used. # @!attribute [rw] voice_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in voice conversations. If not set, default # prompt will be used. class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#prompt_config ⇒ ::Google::Cloud::Ces::V1::GoogleSearchTool::PromptConfig
Returns Optional. Prompt instructions passed to planner on how the search results should be processed for text and voice.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'proto_docs/google/cloud/ces/v1/google_search_tool.rb', line 52 class GoogleSearchTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Prompt settings used by the model when processing or summarizing the # google search results. # @!attribute [rw] text_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in chat conversations. If not set, default # prompt will be used. # @!attribute [rw] voice_prompt # @return [::String] # Optional. Defines the prompt used for the system instructions when # interacting with the agent in voice conversations. If not set, default # prompt will be used. class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |