Class: Google::Cloud::Ces::V1::ImportAppResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ImportAppResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Response message for AgentService.ImportApp.
Instance Attribute Summary collapse
-
#name ⇒ ::String
The resource name of the app that was imported.
-
#warnings ⇒ ::Array<::String>
Warning messages generated during the import process.
Instance Attribute Details
#name ⇒ ::String
Returns The resource name of the app that was imported.
279 280 281 282 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 279 class ImportAppResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warnings ⇒ ::Array<::String>
Returns Warning messages generated during the import process. If errors occur for specific resources, they will not be included in the imported app and the error will be mentioned here.
279 280 281 282 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 279 class ImportAppResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |