Class: Google::Cloud::Ces::V1::ListConversationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ListConversationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Request message for AgentService.ListConversations.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#source ⇒ ::Google::Cloud::Ces::V1::Conversation::Source
Optional.
-
#sources ⇒ ::Array<::Google::Cloud::Ces::V1::Conversation::Source>
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter to be applied when listing the conversations. See https://google.aip.dev/160 for more details.
661 662 663 664 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 661 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
661 662 663 664 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 661 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The next_page_token value returned from a previous list AgentService.ListConversations call.
661 662 663 664 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 661 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the app to list conversations from.
661 662 663 664 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 661 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::Google::Cloud::Ces::V1::Conversation::Source
Returns Optional. Indicate the source of the conversation. If not set, Source.Live
will be applied by default. Will be deprecated in favor of sources field.
661 662 663 664 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 661 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sources ⇒ ::Array<::Google::Cloud::Ces::V1::Conversation::Source>
Returns Optional. Indicate the sources of the conversations. If not set, all available sources will be applied by default.
661 662 663 664 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 661 class ListConversationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |