Class: Google::Cloud::Ces::V1::ListConversationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ListConversationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Response message for AgentService.ListConversations.
Instance Attribute Summary collapse
-
#conversations ⇒ ::Array<::Google::Cloud::Ces::V1::Conversation>
The list of conversations.
-
#next_page_token ⇒ ::String
A token that can be sent as ListConversationsRequest.page_token to retrieve the next page.
Instance Attribute Details
#conversations ⇒ ::Array<::Google::Cloud::Ces::V1::Conversation>
Returns The list of conversations.
677 678 679 680 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 677 class ListConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as ListConversationsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.
677 678 679 680 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 677 class ListConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |