Class: Google::Cloud::Ces::V1::ListToolsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ListToolsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/agent_service.rb
Overview
Response message for AgentService.ListTools.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that can be sent as ListToolsRequest.page_token to retrieve the next page.
-
#tools ⇒ ::Array<::Google::Cloud::Ces::V1::Tool>
The list of tools.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that can be sent as ListToolsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.
561 562 563 564 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 561 class ListToolsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tools ⇒ ::Array<::Google::Cloud::Ces::V1::Tool>
Returns The list of tools.
561 562 563 564 |
# File 'proto_docs/google/cloud/ces/v1/agent_service.rb', line 561 class ListToolsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |