Class: Google::Cloud::Ces::V1::McpTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::McpTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/mcp_tool.rb
Overview
An MCP tool. See https://modelcontextprotocol.io/specification/2025-06-18/server/tools for more details.
Defined Under Namespace
Classes: CustomHeadersEntry
Instance Attribute Summary collapse
-
#api_authentication ⇒ ::Google::Cloud::Ces::V1::ApiAuthentication
Optional.
-
#custom_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#description ⇒ ::String
Optional.
-
#input_schema ⇒ ::Google::Cloud::Ces::V1::Schema
Optional.
-
#name ⇒ ::String
Required.
-
#output_schema ⇒ ::Google::Cloud::Ces::V1::Schema
Optional.
-
#server_address ⇒ ::String
Required.
-
#service_directory_config ⇒ ::Google::Cloud::Ces::V1::ServiceDirectoryConfig
Optional.
-
#tls_config ⇒ ::Google::Cloud::Ces::V1::TlsConfig
Optional.
Instance Attribute Details
#api_authentication ⇒ ::Google::Cloud::Ces::V1::ApiAuthentication
Returns Optional. Authentication information required to execute the tool against the MCP server. For bearer token authentication, the token applies only to tool execution, not to listing tools. This requires that tools can be listed without authentication.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The custom headers to send in the request to the MCP server. The
values must be in the format $context.variables.<name_of_variable> and
can be set in the session variables. See
https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool/open-api#openapi-injection
for more details.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. The description of the MCP tool.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#input_schema ⇒ ::Google::Cloud::Ces::V1::Schema
Returns Optional. The schema of the input arguments of the MCP tool.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The name of the MCP tool.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#output_schema ⇒ ::Google::Cloud::Ces::V1::Schema
Returns Optional. The schema of the output arguments of the MCP tool.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#server_address ⇒ ::String
Returns Required. The server address of the MCP server, e.g., "https://example.com/mcp/". If the server is built with the MCP SDK, the url should be suffixed with "/mcp/". Only Streamable HTTP transport based servers are supported. This is the same as the server_address in the McpToolset. See https://modelcontextprotocol.io/specification/2025-03-26/basic/transports#streamable-http for more details.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_directory_config ⇒ ::Google::Cloud::Ces::V1::ServiceDirectoryConfig
Returns Optional. Service Directory configuration for VPC-SC, used to resolve service names within a perimeter.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tls_config ⇒ ::Google::Cloud::Ces::V1::TlsConfig
Returns Optional. The TLS configuration. Includes the custom server certificates that the client should trust.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'proto_docs/google/cloud/ces/v1/mcp_tool.rb', line 69 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |