Class: Google::Cloud::Ces::V1::McpToolset
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::McpToolset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/mcp_toolset.rb
Overview
A toolset that contains a list of tools that are offered by the MCP server.
Defined Under Namespace
Classes: CustomHeadersEntry
Instance Attribute Summary collapse
-
#api_authentication ⇒ ::Google::Cloud::Ces::V1::ApiAuthentication
Optional.
-
#custom_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#server_address ⇒ ::String
Required.
-
#service_directory_config ⇒ ::Google::Cloud::Ces::V1::ServiceDirectoryConfig
Optional.
-
#tls_config ⇒ ::Google::Cloud::Ces::V1::TlsConfig
Optional.
Instance Attribute Details
#api_authentication ⇒ ::Google::Cloud::Ces::V1::ApiAuthentication
Returns Optional. Authentication information required to access tools and execute a tool against the MCP server. For bearer token authentication, the token applies only to tool execution, not to listing tools. This requires that tools can be listed without authentication.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1/mcp_toolset.rb', line 55 class McpToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#custom_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The custom headers to send in the request to the MCP server. The
values must be in the format $context.variables.<name_of_variable> and
can be set in the session variables. See
https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool/open-api#openapi-injection
for more details.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1/mcp_toolset.rb', line 55 class McpToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#server_address ⇒ ::String
Returns Required. The address of the MCP server, for example, "https://example.com/mcp/". If the server is built with the MCP SDK, the url should be suffixed with "/mcp/". Only Streamable HTTP transport based servers are supported. See https://modelcontextprotocol.io/specification/2025-03-26/basic/transports#streamable-http for more details.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1/mcp_toolset.rb', line 55 class McpToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_directory_config ⇒ ::Google::Cloud::Ces::V1::ServiceDirectoryConfig
Returns Optional. Service Directory configuration for VPC-SC, used to resolve service names within a perimeter.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1/mcp_toolset.rb', line 55 class McpToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tls_config ⇒ ::Google::Cloud::Ces::V1::TlsConfig
Returns Optional. The TLS configuration. Includes the custom server certificates that the client should trust.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1/mcp_toolset.rb', line 55 class McpToolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |