Class: Google::Cloud::Ces::V1::Message
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::Message
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/example.rb
Overview
A message within a conversation.
Instance Attribute Summary collapse
-
#chunks ⇒ ::Array<::Google::Cloud::Ces::V1::Chunk>
Optional.
-
#event_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#role ⇒ ::String
Optional.
Instance Attribute Details
#chunks ⇒ ::Array<::Google::Cloud::Ces::V1::Chunk>
Returns Optional. Content of the message as a series of chunks.
77 78 79 80 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 77 class Message include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Timestamp when the message was sent or received. Should not be used if the message is part of an example.
77 78 79 80 |
# File 'proto_docs/google/cloud/ces/v1/example.rb', line 77 class Message include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |