Class: Google::Cloud::Ces::V1::RetrieveToolSchemaResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::RetrieveToolSchemaResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/tool_service.rb
Overview
Response message for ToolService.RetrieveToolSchema.
Instance Attribute Summary collapse
-
#input_schema ⇒ ::Google::Cloud::Ces::V1::Schema
The schema of the tool input parameters.
-
#output_schema ⇒ ::Google::Cloud::Ces::V1::Schema
The schema of the tool output parameters.
-
#tool ⇒ ::String
The name of the tool that the schema is for.
-
#toolset_tool ⇒ ::Google::Cloud::Ces::V1::ToolsetTool
The toolset tool that the schema is for.
Instance Attribute Details
#input_schema ⇒ ::Google::Cloud::Ces::V1::Schema
Returns The schema of the tool input parameters.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/tool_service.rb', line 135 class RetrieveToolSchemaResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_schema ⇒ ::Google::Cloud::Ces::V1::Schema
Returns The schema of the tool output parameters.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/tool_service.rb', line 135 class RetrieveToolSchemaResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String
Returns The name of the tool that the schema is for.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/tool_service.rb', line 135 class RetrieveToolSchemaResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_tool ⇒ ::Google::Cloud::Ces::V1::ToolsetTool
Returns The toolset tool that the schema is for.
Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
135 136 137 138 |
# File 'proto_docs/google/cloud/ces/v1/tool_service.rb', line 135 class RetrieveToolSchemaResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |