Class: Google::Cloud::Ces::V1::ServiceAccountAuthConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::ServiceAccountAuthConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/auth.rb
Overview
Configurations for authentication using a custom service account.
Instance Attribute Summary collapse
-
#scopes ⇒ ::Array<::String>
Optional.
-
#service_account ⇒ ::String
Required.
Instance Attribute Details
#scopes ⇒ ::Array<::String>
Returns Optional. The OAuth scopes to grant. If not specified, the default scope
https://www.googleapis.com/auth/cloud-platform is used.
120 121 122 123 |
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 120 class ServiceAccountAuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_account ⇒ ::String
Returns Required. The email address of the service account used for authentication.
CES uses this service account to exchange an access token and the access
token is then sent in the Authorization header of the request.
The service account must have the
roles/iam.serviceAccountTokenCreator role granted to the
CES service agent
service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.
120 121 122 123 |
# File 'proto_docs/google/cloud/ces/v1/auth.rb', line 120 class ServiceAccountAuthConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |