Class: Google::Cloud::Ces::V1::SessionOutput
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::SessionOutput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/session_service.rb
Overview
Output for the session.
Defined Under Namespace
Classes: DiagnosticInfo
Instance Attribute Summary collapse
-
#audio ⇒ ::String
Output audio from the CES agent.
-
#citations ⇒ ::Google::Cloud::Ces::V1::Citations
Citations that provide the source information for the agent's generated text.
-
#diagnostic_info ⇒ ::Google::Cloud::Ces::V1::SessionOutput::DiagnosticInfo
Optional.
-
#end_session ⇒ ::Google::Cloud::Ces::V1::EndSession
Indicates the session has ended.
-
#google_search_suggestions ⇒ ::Google::Cloud::Ces::V1::GoogleSearchSuggestions
The suggestions returned from Google Search as a result of invoking the GoogleSearchTool.
-
#payload ⇒ ::Google::Protobuf::Struct
Custom payload with structured output from the CES agent.
-
#text ⇒ ::String
Output text from the CES agent.
-
#tool_calls ⇒ ::Google::Cloud::Ces::V1::ToolCalls
Request for the client to execute the tools.
-
#turn_completed ⇒ ::Boolean
If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn.
-
#turn_index ⇒ ::Integer
Indicates the sequential order of conversation turn to which this output belongs to, starting from 1.
Instance Attribute Details
#audio ⇒ ::String
Returns Output audio from the CES agent.
Note: The following fields are mutually exclusive: audio, text, tool_calls, citations, google_search_suggestions, end_session, payload. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#citations ⇒ ::Google::Cloud::Ces::V1::Citations
Returns Citations that provide the source information for the agent's generated text.
Note: The following fields are mutually exclusive: citations, text, audio, tool_calls, google_search_suggestions, end_session, payload. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#diagnostic_info ⇒ ::Google::Cloud::Ces::V1::SessionOutput::DiagnosticInfo
Returns Optional. Diagnostic information contains execution details during the
processing of the input. Only populated in the last SessionOutput (with
turn_completed=true) for each turn.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#end_session ⇒ ::Google::Cloud::Ces::V1::EndSession
Returns Indicates the session has ended.
Note: The following fields are mutually exclusive: end_session, text, audio, tool_calls, citations, google_search_suggestions, payload. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#google_search_suggestions ⇒ ::Google::Cloud::Ces::V1::GoogleSearchSuggestions
Returns The suggestions returned from Google Search as a result of invoking the GoogleSearchTool.
Note: The following fields are mutually exclusive: google_search_suggestions, text, audio, tool_calls, citations, end_session, payload. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#payload ⇒ ::Google::Protobuf::Struct
Returns Custom payload with structured output from the CES agent.
Note: The following fields are mutually exclusive: payload, text, audio, tool_calls, citations, google_search_suggestions, end_session. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#text ⇒ ::String
Returns Output text from the CES agent.
Note: The following fields are mutually exclusive: text, audio, tool_calls, citations, google_search_suggestions, end_session, payload. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tool_calls ⇒ ::Google::Cloud::Ces::V1::ToolCalls
Returns Request for the client to execute the tools.
Note: The following fields are mutually exclusive: tool_calls, text, audio, citations, google_search_suggestions, end_session, payload. If a field in that set is populated, all other fields in the set will automatically be cleared.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#turn_completed ⇒ ::Boolean
Returns If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#turn_index ⇒ ::Integer
Returns Indicates the sequential order of conversation turn to which this output belongs to, starting from 1.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 311 class SessionOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains execution details during the processing. # @!attribute [rw] messages # @return [::Array<::Google::Cloud::Ces::V1::Message>] # List of the messages that happened during the processing. # @!attribute [rw] root_span # @return [::Google::Cloud::Ces::V1::Span] # A trace of the entire request processing, represented as a root span. # This span can contain nested child spans for specific operations. class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |