Class: Google::Cloud::Ces::V1::SessionOutput::DiagnosticInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1::SessionOutput::DiagnosticInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1/session_service.rb
Overview
Contains execution details during the processing.
Instance Attribute Summary collapse
-
#messages ⇒ ::Array<::Google::Cloud::Ces::V1::Message>
List of the messages that happened during the processing.
-
#root_span ⇒ ::Google::Cloud::Ces::V1::Span
A trace of the entire request processing, represented as a root span.
Instance Attribute Details
#messages ⇒ ::Array<::Google::Cloud::Ces::V1::Message>
Returns List of the messages that happened during the processing.
323 324 325 326 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 323 class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#root_span ⇒ ::Google::Cloud::Ces::V1::Span
Returns A trace of the entire request processing, represented as a root span. This span can contain nested child spans for specific operations.
323 324 325 326 |
# File 'proto_docs/google/cloud/ces/v1/session_service.rb', line 323 class DiagnosticInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |